@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.72 2003/12/30 19:56:40 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.74 2004/01/05 13:38:19 fuyu Exp $
  */
 
 #include "config.h"
@@ -92,7 +92,7 @@ static void save_initial_thread_view_position(BBSThreadView *view,
 
 static void show_popup(OchushaApplication *application,
 		       OchushaBBSThread *thread,
-		       const gchar *link, gint x_pos, gint y_pos,
+		       const gchar *link, int x_pos, int y_pos,
 		       BBSThreadView *parent);
 static gboolean popup_delay_timeout(PopupContext *popup_context);
 static void show_popup_real(PopupContext *popup_context);
@@ -103,10 +103,10 @@ static void render_bbs_thread(WorkerThread *employee, gpointer args);
 static gboolean start_thread_rendering(OchushaBBSThread *thread,
 				       const gchar *title,
 				       gpointer user_data);
-static gboolean render_response(OchushaBBSThread *thread, gint number,
+static gboolean render_response(OchushaBBSThread *thread, int number,
 				const OchushaBBSResponse *response,
 				gpointer user_data);
-static gboolean render_broken_response(OchushaBBSThread *thread, gint number,
+static gboolean render_broken_response(OchushaBBSThread *thread, int number,
 				       gpointer user_data);
 static gboolean end_thread_rendering(OchushaBBSThread *thread,
 				     gboolean finished,
@@ -153,8 +153,8 @@ typedef struct _RendererContext
   OchushaBBSThread *thread;
   BBSThreadGUIInfo *info;
   OchushaApplication *application;
-  gint last_read_number;
-  gint last_rendered_response;
+  int last_read_number;
+  int last_rendered_response;
   gboolean title_shown;
 
   gchar *link;
@@ -204,8 +204,8 @@ struct _PopupContext
   gchar *url;
   guint delay_id;
   guint close_delay_id;
-  gint x_pos;
-  gint y_pos;
+  int x_pos;
+  int y_pos;
 
   gboolean now_pointed;
 };
@@ -262,7 +262,7 @@ static GtkWidget *font_selection_dialog = NULL;
 
 
 static void
-font_selection_dialog_response_cb(GtkWidget *dialog, gint response_id,
+font_selection_dialog_response_cb(GtkWidget *dialog, int response_id,
 				  OchushaApplication *application)
 {
   GtkFontSelectionDialog *font_selection;
@@ -528,7 +528,7 @@ initialize_thread_ui(OchushaApplication *application)
 	NULL						/* type */
       },
     };
-  gint nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
+  int nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
 
   GtkItemFactoryEntry response_menu_items[] =
     {
@@ -540,7 +540,7 @@ initialize_thread_ui(OchushaApplication *application)
 	NULL						/* type */
       },
     };
-  gint response_nmenu_items
+  int response_nmenu_items
     = sizeof(response_menu_items) / sizeof(response_menu_items[0]);
 
   link_popup_menu_item_factory = gtk_item_factory_new(GTK_TYPE_MENU,
@@ -701,8 +701,8 @@ typedef struct _BBSThreadJobArgs
   BBSThreadView *view;
   IconLabel *tab_label;
   OchushaAsyncBuffer *buffer;
-  gint start;
-  gint number_of_responses;
+  int start;
+  int number_of_responses;
   gboolean refresh;
 } BBSThreadJobArgs;
 
@@ -1430,24 +1430,35 @@ insert_bookmark(BBSThreadView *view, OchushaBBSThread *thread, int res_num,
   if (info->bookmark != NULL && info->bookmark_response_number == res_num)
     return;
 
-  bookmark_text = application->bookmark_text;
-  
-  if (bookmark_text == NULL || *bookmark_text == '\0')
+  if (application->hide_bookmark)
+    bookmark = NULL;
+  else
     {
-      if (application->bookmark_text != NULL)
-	G_FREE(application->bookmark_text);
-      bookmark_text = G_STRDUP(_("==== My bookmark: I have read above. ===="));
-      application->bookmark_text = bookmark_text;
+      bookmark_text = application->bookmark_text;
+  
+      if (bookmark_text == NULL || *bookmark_text == '\0')
+	{
+	  if (application->bookmark_text != NULL)
+	    G_FREE(application->bookmark_text);
+	  bookmark_text
+	    = G_STRDUP(_("==== My bookmark: I have read above. ===="));
+	  application->bookmark_text = bookmark_text;
+	}
+
+      bookmark = gtk_button_new_with_label(bookmark_text);
+      GTK_WIDGET_UNSET_FLAGS(bookmark, GTK_CAN_FOCUS);
+
+      gtk_widget_set_name(bookmark, "mybookmark");
+
+      g_object_set_data(G_OBJECT(bookmark), "application", application);
+      g_object_set_data(G_OBJECT(bookmark), "thread", thread);
+
+      g_signal_connect(G_OBJECT(bookmark), "clicked",
+		       G_CALLBACK(bookmark_clicked_cb), view);
+      g_signal_connect(G_OBJECT(bookmark), "destroy",
+		       G_CALLBACK(bookmark_destroy_cb), info);
     }
 
-  bookmark = gtk_button_new_with_label(bookmark_text);
-  GTK_WIDGET_UNSET_FLAGS(bookmark, GTK_CAN_FOCUS);
-
-  gtk_widget_set_name(bookmark, "mybookmark");
-
-  g_object_set_data(G_OBJECT(bookmark), "application", application);
-  g_object_set_data(G_OBJECT(bookmark), "thread", thread);
-
   if (info->bookmark != NULL)
     {
       bbs_thread_view_remove_widget(view, info->bookmark);
@@ -1461,11 +1472,6 @@ insert_bookmark(BBSThreadView *view, OchushaBBSThread *thread, int res_num,
 	}
     }
 
-  g_signal_connect(G_OBJECT(bookmark), "clicked",
-		   G_CALLBACK(bookmark_clicked_cb), view);
-  g_signal_connect(G_OBJECT(bookmark), "destroy",
-		   G_CALLBACK(bookmark_destroy_cb), info);
-
   if (info->last_read != NULL)
     bbs_thread_view_delete_mark(view, info->last_read);
 
@@ -1476,19 +1482,23 @@ insert_bookmark(BBSThreadView *view, OchushaBBSThread *thread, int res_num,
 	  = bbs_thread_view_create_mark_at_offset(view, offsets[res_num]);
       else
 	info->last_read = bbs_thread_view_create_mark(view);
-      bbs_thread_view_append_widget(view, bookmark);
+      if (!application->hide_bookmark)
+	bbs_thread_view_append_widget(view, bookmark);
     }
   else
     {
       info->last_read
 	= bbs_thread_view_create_mark_at_offset(view, offsets[res_num]);
-      bbs_thread_view_insert_widget_at_offset(view, bookmark,
-					      offsets[res_num + 1]);
-      for (i = res_num + 1; i < offsets_length; i++)
+      if (!application->hide_bookmark)
 	{
-	  if (offsets[i] == 0)
-	    break;
-	  offsets[i]++;
+	  bbs_thread_view_insert_widget_at_offset(view, bookmark,
+						  offsets[res_num + 1]);
+	  for (i = res_num + 1; i < offsets_length; i++)
+	    {
+	      if (offsets[i] == 0)
+		break;
+	      offsets[i]++;
+	    }
 	}
     }
 
@@ -1862,7 +1872,7 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 #define LARGE_COLON		"\357\274\232"
 
 static gboolean
-render_response(OchushaBBSThread *thread, gint number,
+render_response(OchushaBBSThread *thread, int number,
 		const OchushaBBSResponse *response,
 		gpointer user_data)
 {
@@ -2086,7 +2096,7 @@ render_response(OchushaBBSThread *thread, gint number,
 
 
 static gboolean
-render_broken_response(OchushaBBSThread *thread, gint number,
+render_broken_response(OchushaBBSThread *thread, int number,
 		       gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
@@ -2657,8 +2667,8 @@ popup_expose_event_cb(GtkWidget *widget, GdkEventExpose *event,
 
 	  if (screen != NULL)
 	    {
-	      gint screen_width = gdk_screen_get_width(screen);
-	      gint widget_width = requisition.width + THREAD_VIEW_EXTRA_WIDTH;
+	      int screen_width = gdk_screen_get_width(screen);
+	      int widget_width = requisition.width + THREAD_VIEW_EXTRA_WIDTH;
 	      if (screen_width > 0
 		  && (popup_context->x_pos + widget_width) > screen_width)
 		{
@@ -2766,7 +2776,7 @@ popup_window_leave_notify_cb(GtkWidget *widget,
 static void
 render_popup_response(PopupContext *popup_context,
 		      OchushaBBSThread *thread, OchushaAsyncBuffer *buffer,
-		      gint response_from, gint num_responses)
+		      int response_from, int num_responses)
 {
   OchushaApplication *application
     = popup_context->renderer_context.application;
@@ -2852,16 +2862,16 @@ render_popup_response(PopupContext *popup_context,
 
 static void
 show_popup(OchushaApplication *application, OchushaBBSThread *thread,
-	   const gchar *link, gint x_pos, gint y_pos, BBSThreadView *parent)
+	   const gchar *link, int x_pos, int y_pos, BBSThreadView *parent)
 {
   /*
    * MEMO: gdk_threads_enter()줿ĶƤФƤ롣
    */
   PopupContext *popup_context;
   OchushaAsyncBuffer *buffer;
-  gint response_from = 0;
-  gint response_to = 0;
-  gint num_responses;
+  int response_from = 0;
+  int response_to = 0;
+  int num_responses;
 
   CHECK_THREADS_ENTERED();
 
@@ -2968,11 +2978,11 @@ show_popup_real(PopupContext *popup_context)
 
   if (popup_context->renderer_context.view != NULL)
     {
-      gint w, h;
+      int w, h;
       gboolean use_two_steps_hack = FALSE;
       GtkRequisition requisition = { 0, 0 };
       GdkScreen *screen = gtk_widget_get_screen(popup_context->popup_window);
-      gint screen_width = screen != NULL ? gdk_screen_get_width(screen) : 0;
+      int screen_width = screen != NULL ? gdk_screen_get_width(screen) : 0;
 
       gtk_widget_size_request(GTK_WIDGET(popup_context->renderer_context.view),
 			      &requisition);
