@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.19 2003/12/30 17:21:46 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.20 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -100,7 +100,7 @@ typedef struct _BBSThreadGUIInfo
   OchushaAsyncBuffer *response_source_buffer;
 
   /* Ǹ˳ưʹߤΥ */
-  gint view_ignored;
+  int view_ignored;
 
   /* 񤭹ѥ */
   GtkWidget *write_dialog;
