@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.34 2003/12/30 19:56:40 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.36 2004/01/01 18:53:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -419,6 +419,13 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
 			       "scroll_view", 1,
 			       GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_PAGE_BACKWARD);
 
+  gtk_binding_entry_add_signal(binding_set, GDK_Down, 0,
+			       "scroll_view", 1,
+			       GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_STEP_FORWARD);
+  gtk_binding_entry_add_signal(binding_set, GDK_Up, 0,
+			       "scroll_view", 1,
+			       GTK_TYPE_SCROLL_TYPE, GTK_SCROLL_STEP_BACKWARD);
+
   gtk_binding_entry_add_signal(binding_set, GDK_S, GDK_CONTROL_MASK,
 			       "interactive_search", 1,
 			       G_TYPE_INT,
@@ -1486,10 +1493,8 @@ bbs_thread_view_scroll_to_offsets(BBSThreadView *view,
 				     + end_offset);
   gtk_text_buffer_move_mark(view->text_buffer, view->selection_bound_mark,
 			    &iter);
-  gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(view),
-				     view->insert_mark);
-  gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(view),
-				     view->selection_bound_mark);
+  gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(view), view->insert_mark,
+			       0.1, TRUE, 0.2, 0.2);
 }
 
 
