@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.18 2003/12/18 15:56:34 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.19 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -84,7 +84,7 @@ struct _BBSThreadView
   GSList *tags;
 
   /* ʥطǻȤ */
-  gint last_offset;
+  int last_offset;
   OchushaBBSThread *thread;
   GHashTable *link_table;	/* offset=>linkʥơ֥ */
 
@@ -92,7 +92,7 @@ struct _BBSThreadView
 
 
   /* طǻȤ */
-  gint last_match_offset;
+  int last_match_offset;
   guint idle_search_func;
   GtkTextMark *insert_mark;
   GtkTextMark *selection_bound_mark;
@@ -137,7 +137,7 @@ struct _BBSThreadViewClass
   void (*view_leave_notify)(BBSThreadView *bbs_thread_view,
 			    GdkEventCrossing *event);
 
-  void (*scroll_to)(BBSThreadView *bbs_thread_view, gint to_where);
+  void (*scroll_to)(BBSThreadView *bbs_thread_view, int to_where);
   void (*scroll_view)(BBSThreadView *bbs_thread_view, GtkScrollType scroll);
   void (*interactive_search)(BBSThreadView *bbs_thread_view,
 			     BBSThreadViewSearchAction action);
@@ -156,7 +156,7 @@ OchushaBBSThread *bbs_thread_view_get_thread(BBSThreadView *view);
 
 void bbs_thread_view_clear(BBSThreadView *view);
 
-gint bbs_thread_view_get_current_offset(BBSThreadView *view);
+int bbs_thread_view_get_current_offset(BBSThreadView *view);
 GtkTextMark *bbs_thread_view_create_mark(BBSThreadView *view);
 void bbs_thread_view_delete_mark(BBSThreadView *view, GtkTextMark *mark);
 void bbs_thread_view_append_text(BBSThreadView *view, const gchar *text,
@@ -170,7 +170,7 @@ void bbs_thread_view_append_text_as_sage(BBSThreadView *view,
 void bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget);
 void bbs_thread_view_insert_widget_at_offset(BBSThreadView *view,
 					     GtkWidget *widget,
-					     gint offset);
+					     int offset);
 void bbs_thread_view_remove_widget(BBSThreadView *view, GtkWidget *widget);
 
 GtkTextTag *bbs_thread_view_get_tag_by_name(BBSThreadView *view,
@@ -184,10 +184,10 @@ void bbs_thread_view_pop_tags(BBSThreadView *view, GtkTextTag *tag);
 void bbs_thread_view_scroll_to_start(BBSThreadView *view);
 void bbs_thread_view_scroll_to_end(BBSThreadView *view);
 void bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark);
-gint bbs_thread_view_scroll_to_offset(BBSThreadView *view, gint offset);
+int bbs_thread_view_scroll_to_offset(BBSThreadView *view, int offset);
 GtkTextMark *bbs_thread_view_create_mark_at_offset(BBSThreadView *view,
-						   gint offset);
-void bbs_thread_view_place_cursor_at_offset(BBSThreadView *view, gint offset);
+						   int offset);
+void bbs_thread_view_place_cursor_at_offset(BBSThreadView *view, int offset);
 
 
 gboolean bbs_thread_view_find(BBSThreadView *view, const gchar *key,
