@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: board_properties.c,v 1.8 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: board_properties.c,v 1.9 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -86,7 +86,7 @@ static void setting_changed_cb(ThreadlistFilterSetting *setting,
 static void restore_default_cb(ThreadlistFilterSetting *setting,
 			       DialogStates *states);
 static void apply_current_states(GtkWidget *dialog, DialogStates *states);
-static void board_properties_response_cb(GtkWidget *dialog, gint response_id,
+static void board_properties_response_cb(GtkWidget *dialog, int response_id,
 					 DialogStates *states);
 static void board_local_a_bone_toggled_cb(GtkToggleButton *button,
 					  DialogStates *states);
@@ -411,7 +411,7 @@ apply_current_states(GtkWidget *dialog, DialogStates *states)
 
 
 static void
-board_properties_response_cb(GtkWidget *dialog, gint response_id,
+board_properties_response_cb(GtkWidget *dialog, int response_id,
 			     DialogStates *states)
 {
   gboolean close_dialog = TRUE;
