@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.51 2003/12/30 20:48:11 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.53 2004/01/01 23:05:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -137,7 +137,7 @@ static void refresh_board_button_cb(GtkWidget *widget,
 				    OchushaApplication *application);
 static void start_threadlist_search_button_cb(GtkWidget *widget,
 					      OchushaApplication *application);
-static void new_thread_dialog_response_cb(GtkWidget *dialog, gint response_id,
+static void new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 					  OchushaApplication *application);
 static GtkWidget *create_new_thread_dialog(OchushaApplication *application,
 					   OchushaBulletinBoard *board);
@@ -331,6 +331,18 @@ initialize_boardlist(OchushaApplication *application)
 			   application,
 			   0);
 
+#if 0
+  {
+    GtkWidget *tmp_widget;
+    tmp_widget = gtk_toggle_button_new_with_label(GTK_STOCK_SORT_ASCENDING);
+    GTK_WIDGET_UNSET_FLAGS(tmp_widget, GTK_CAN_FOCUS);
+    gtk_button_set_use_stock(GTK_BUTTON(tmp_widget), TRUE);
+    gtk_toolbar_prepend_widget(toolbar, tmp_widget,
+			       _("Sort Threadlist by Weight"),
+			       "sort_threadlist_by_weight");
+  }
+#endif
+
 #if DEBUG_WIDGET_MOST
   g_signal_connect(G_OBJECT(application->boardlist_view), "select_category",
 		   G_CALLBACK(select_category_cb), application);
@@ -604,7 +616,7 @@ static ThreadlistSearchQueryData search_query_data =
 
 
 static void
-text_search_window_response_cb(TextSearchWindow *window, gint response_id,
+text_search_window_response_cb(TextSearchWindow *window, int response_id,
 			       OchushaApplication *application)
 {
   MAIN_THREAD_EVENT_CALLBACK();
@@ -1554,7 +1566,7 @@ start_threadlist_search_button_cb(GtkWidget *widget,
 
 
 static void
-new_thread_dialog_response_cb(GtkWidget *dialog, gint response_id,
+new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 			      OchushaApplication *application)
 {
   OchushaBulletinBoard *board = g_object_get_data(G_OBJECT(dialog), "board");
