@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.18 2003/12/30 17:21:46 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.22 2004/01/04 06:45:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -49,6 +49,8 @@
 static void boardlist_view_class_init(BoardlistViewClass *klass);
 static void popup_menu_callback(gpointer data, guint action,
 				GtkWidget *widget);
+static void popup_menu_callback2(gpointer data, guint action,
+				 GtkWidget *widget);
 static void popup_menu_destructed_cb(gpointer data);
 static void boardlist_view_init(BoardlistView *view);
 
@@ -56,9 +58,9 @@ static void boardlist_view_finalize(GObject *object);
 static void boardlist_view_destroy(GtkObject *object);
 
 static void boardlist_view_do_on_selection(BoardlistView *view,
-					   gint what_to_do);
+					   int what_to_do);
 static void boardlist_view_do_on_item_at_cursor(BoardlistView *view,
-						gint what_to_do);
+						int what_to_do);
 
 static void tree_view_row_expanded_cb(GtkTreeView *tree_view,
 				      GtkTreeIter *iter, GtkTreePath *path,
@@ -66,12 +68,10 @@ static void tree_view_row_expanded_cb(GtkTreeView *tree_view,
 static void tree_view_row_collapsed_cb(GtkTreeView *tree_view,
 				       GtkTreeIter *iter, GtkTreePath *path,
 				       BoardlistView *view);
-static gboolean tree_view_button_press_event_cb(GtkWidget *widget,
-						GdkEventButton *event,
-						BoardlistView *view);
-static gboolean tree_view_button_release_event_cb(GtkWidget *widget,
-						  GdkEventButton *event,
-						  BoardlistView *view);
+static gboolean boardlist_view_button_press(GtkWidget *widget,
+					    GdkEventButton *event);
+static gboolean boardlist_view_button_release(GtkWidget *widget,
+					      GdkEventButton *event);
 static void decorate_boardlist_entry(GtkTreeViewColumn *tree_column,
 				     GtkCellRenderer *renderer,
 				     GtkTreeModel *tree_model,
@@ -108,10 +108,10 @@ boardlist_view_get_type(void)
 }
 
 
-typedef struct _TreeNodeInfo
+typedef struct _CategoryNodeInfo
 {
-  GtkTreeIter iter;
-} TreeNodeInfo;
+  GtkTreeRowReference *reference;
+} CategoryNodeInfo;
 
 
 enum {
@@ -156,35 +156,34 @@ enum {
 
 
 static GtkTreeViewClass *parent_class = NULL;
-static gint boardlist_view_signals[LAST_SIGNAL] =
+static int boardlist_view_signals[LAST_SIGNAL] =
   { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 static GtkItemFactory *popup_menu_item_factory = NULL;
+static GtkItemFactory *popup_menu_item_factory2 = NULL;
 static GQuark node_info_id;
 
 static char *list_entry_color[4] = { NULL, NULL, NULL, NULL };
 
 
-#if TRACE_MEMORY_USAGE
 static void
-trace_free(gpointer pointer)
+category_node_info_free(CategoryNodeInfo *info)
 {
-  G_FREE(pointer);
+  gtk_tree_row_reference_free(info->reference);
+  info->reference = NULL;
+  G_FREE(info);
 }
-#define TRACE_FREE	trace_free
-#else
-#define TRACE_FREE	g_free
-#endif
 
 
-static TreeNodeInfo *
+static CategoryNodeInfo *
 ensure_node_info(GObject *object)
 {
-  TreeNodeInfo *info = g_object_get_qdata(object, node_info_id);
+  CategoryNodeInfo *info = g_object_get_qdata(object, node_info_id);
+
   if (info == NULL)
     {
-      info = G_NEW0(TreeNodeInfo, 1);
+      info = G_NEW0(CategoryNodeInfo, 1);
       g_object_set_qdata_full(object, node_info_id,
-			      info, (GDestroyNotify)TRACE_FREE);
+			      info, (GDestroyNotify)category_node_info_free);
     }
 
   return info;
@@ -259,7 +258,68 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 	NULL					/* type */
       },
     };
-  gint nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
+  int nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
+
+  GtkItemFactoryEntry menu_items2[] =
+    {
+      {
+	_("/_Open"),				/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback2,			/* callback_func */
+	POPUP_MENU_OPEN_SELECTION,		/* act */
+	NULL					/* type */
+      },
+      {
+	_("/Open Boards in _Tab"),		/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback2,			/* callback_func */
+	POPUP_MENU_OPEN_SELECTION_IN_TAB,	/* act */
+	NULL					/* type */
+      },
+      {
+	_("/Open Boards with Web Browser"),	/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback2,			/* callback_func */
+	POPUP_MENU_OPEN_SELECTION_WITH_BROWSER,	/* act */
+	NULL					/* type */
+      },
+      {
+	_("/-------"),
+	NULL,
+	NULL,
+	0,
+	(char *)"<Separator>"
+      },
+      {
+	_("/Hide(_D)"),				/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback2,			/* callback_func */
+	POPUP_MENU_TOGGLE_HIDE_SELECTION,	/* act */
+	NULL					/* type */
+      },
+      {
+	_("/Kill(_K)"),				/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback2,			/* callback_func */
+	POPUP_MENU_KILL_SELECTION,		/* act */
+	NULL					/* type */
+      },
+      {
+	_("/-------"),
+	NULL,
+	NULL,
+	0,
+	(char *)"<Separator>"
+      },
+      {
+	_("/Copy Board's URL"),			/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback2,			/* callback_func */
+	POPUP_MENU_COPY_BOARD_URL,		/* act */
+	NULL					/* type */
+      },
+    };
+  int nmenu_items2 = sizeof(menu_items2) / sizeof(menu_items2[0]);
 
   popup_menu_item_factory = gtk_item_factory_new(GTK_TYPE_MENU,
 						 "<BoardlistViewPopup>",
@@ -267,6 +327,13 @@ boardlist_view_class_init(BoardlistViewClass *klass)
   gtk_item_factory_create_items(popup_menu_item_factory,
 				nmenu_items, menu_items, NULL);
 
+  popup_menu_item_factory2 = gtk_item_factory_new(GTK_TYPE_MENU,
+						 "<BoardlistViewPopup2>",
+						 NULL);
+  gtk_item_factory_create_items(popup_menu_item_factory2,
+				nmenu_items2, menu_items2, NULL);
+
+
   parent_class = g_type_class_peek_parent(klass);
   binding_set = gtk_binding_set_by_class(klass);
 
@@ -472,7 +539,9 @@ boardlist_view_class_init(BoardlistViewClass *klass)
 			       "move_cursor", 2,
 			       G_TYPE_ENUM, GTK_MOVEMENT_PAGES,
 			       G_TYPE_INT, -1);
-			       
+
+  widget_class->button_press_event = boardlist_view_button_press;
+  widget_class->button_release_event = boardlist_view_button_release;
 
   klass->open_threadlist_view = NULL;
 
@@ -492,7 +561,7 @@ boardlist_view_class_init(BoardlistViewClass *klass)
   klass->do_on_selection = boardlist_view_do_on_selection;
   klass->do_on_item_at_cursor = boardlist_view_do_on_item_at_cursor;
 
-  node_info_id = g_quark_from_static_string("BoardlistView::TreeNodeInfo");
+  node_info_id = g_quark_from_static_string("BoardlistView::CategoryNodeInfo");
 }
 
 
@@ -513,11 +582,194 @@ enum
 };
 
 
+enum
+{
+  TARGET_BOARDLIST_INTERNAL,
+  TARGET_URI_LIST,
+  TARGET_UTF8_STRING,
+  TARGET_STRING,
+  TARGET_TEXT,
+  TARGET_COMPOUND_TEXT
+};
+
+
+#define BOARDLIST_DND_INTERNAL_DATA	"Ochusha::Boardlist::DnD"
+
+static void
+drag_data_received_cb(GtkWidget *widget, GdkDragContext *context,
+		      int x, int y, GtkSelectionData *selection_data,
+		      guint info, guint time, BoardlistView *view)
+{
+#if 0
+  fprintf(stderr, "drag_data_received_cb: is_source=%d actions=0x%x suggested_action=0x%x action=0x%x time=%d\n",
+	  context->is_source, context->actions, context->suggested_action,
+	  context->action, time);
+  fprintf(stderr, "view->last_event_time=%d\n", view->last_event_time);
+#endif
+}
+
+
+static void
+collect_drag_sources(GtkTreeModel *model, GtkTreePath *path,
+		     GtkTreeIter *iter, GSList **list_p)
+{
+  gpointer data = NULL;
+  gtk_tree_model_get(model, iter, BOARDLIST_DATA, &data, -1);
+  g_return_if_fail(data != NULL);
+
+  *list_p = g_slist_append(*list_p, data);
+}
+
+
+static void
+append_uri(gpointer data, gpointer list_p)
+{
+  char **uri_list_p = (char **)list_p;
+
+  if (OCHUSHA_IS_BULLETIN_BOARD(data))
+    {
+      if (*uri_list_p == NULL)
+	*uri_list_p = g_strdup_printf("%s\r\n", ochusha_bulletin_board_get_base_url(OCHUSHA_BULLETIN_BOARD(data)));
+      else
+	{
+	  char *prev_list = *uri_list_p;
+	  *uri_list_p = g_strdup_printf("%s%s\r\n", prev_list, ochusha_bulletin_board_get_base_url(OCHUSHA_BULLETIN_BOARD(data)));
+	  g_free(prev_list);
+	}
+    }
+}
+
+
+static void
+append_utf8_text(gpointer data, gpointer text_p)
+{
+  gchar **utf8_text_p = (gchar **)text_p;
+
+  if (OCHUSHA_IS_BULLETIN_BOARD(data))
+    {
+      OchushaBulletinBoard *board = OCHUSHA_BULLETIN_BOARD(data);
+      if (*utf8_text_p == NULL)
+	*utf8_text_p = g_strdup_printf(_("%s board\n%s\n"),
+				       ochusha_bulletin_board_get_name(board),
+				       ochusha_bulletin_board_get_base_url(board));
+      else
+	{
+	  char *prev_text = *utf8_text_p;
+	  *utf8_text_p = g_strdup_printf(_("%s%s board\n%s\n"),
+					 prev_text,
+					 ochusha_bulletin_board_get_name(board),
+					 ochusha_bulletin_board_get_base_url(board));
+	  g_free(prev_text);
+	}
+    }
+  else if (OCHUSHA_BOARD_CATEGORY(data))
+    {
+      OchushaBoardCategory *cat = OCHUSHA_BOARD_CATEGORY(data);
+      if (*utf8_text_p == NULL)
+	*utf8_text_p = g_strdup_printf(_("Category %s\n"),
+				       ochusha_board_category_get_name(cat));
+      else
+	{
+	  char *prev_text = *utf8_text_p;
+	  *utf8_text_p = g_strdup_printf(_("%sCategory %s\n"),
+					 prev_text,
+					 ochusha_board_category_get_name(cat));
+	  g_free(prev_text);
+	}
+    }
+}
+
+
+static void
+drag_data_get_cb(GtkWidget *widget, GdkDragContext *context,
+		 GtkSelectionData *selection_data, guint info, guint time,
+		 BoardlistView *view)
+{
+  GSList *data_list = NULL;
+  gtk_tree_selection_selected_foreach(view->selection,
+			(GtkTreeSelectionForeachFunc)collect_drag_sources,
+			&data_list);
+  if (view->last_drag_event_data != NULL)
+    {
+      g_slist_free(view->last_drag_event_data);
+      view->last_drag_event_data = NULL;
+    }
+
+  if (data_list != NULL)
+    {
+      switch (info)
+	{
+	case TARGET_BOARDLIST_INTERNAL:
+	  view->last_drag_event_data = data_list;
+	  view->last_event_time = time;
+	  gtk_selection_data_set(selection_data, selection_data->target,
+				 8, BOARDLIST_DND_INTERNAL_DATA,
+				 strlen(BOARDLIST_DND_INTERNAL_DATA));
+	  data_list = NULL;
+	  break;
+
+	case TARGET_URI_LIST:
+	  {
+	    char *uri_list = NULL;
+	    g_slist_foreach(data_list, append_uri, &uri_list);
+	    if (uri_list != NULL)
+	      {
+		gtk_selection_data_set(selection_data, selection_data->target,
+				       8, uri_list, strlen(uri_list));
+		g_free(uri_list);
+	      }
+	    break;
+	  }
+
+	case TARGET_UTF8_STRING:
+	case TARGET_STRING:
+	case TARGET_TEXT:
+	case TARGET_COMPOUND_TEXT:
+	  {
+	    char *utf8_text = NULL;
+	    g_slist_foreach(data_list, append_utf8_text, &utf8_text);
+	    if (utf8_text != NULL)
+	      {
+		gtk_selection_data_set_text(selection_data, utf8_text, -1);
+		g_free(utf8_text);
+	      }
+	    break;
+	  }
+	}
+    }
+
+  if (data_list != NULL)
+    g_slist_free(data_list);
+
+  if (view->last_event_path != NULL)
+    {
+      gtk_tree_path_free(view->last_event_path);
+      view->last_event_path = NULL;
+    }
+}
+
+
 static void
 boardlist_view_init(BoardlistView *view)
 {
   GtkCellRenderer *renderer;
   GtkTreeViewColumn *column;
+  static const GtkTargetEntry drop_types[] =
+    {
+      { "ochusha/boardlist-internal", 0, TARGET_BOARDLIST_INTERNAL }
+    };
+  static int n_drop_types = sizeof(drop_types)/sizeof(drop_types[0]);
+
+  static const GtkTargetEntry drag_types[] =
+    {
+      { "ochusha/boardlist-internal", 0, TARGET_BOARDLIST_INTERNAL },
+      { "text/uri-list", 0, TARGET_URI_LIST },
+      { "UTF8_STRING", 0, TARGET_UTF8_STRING },
+      { "STRING", 0, 0 },
+      { "TEXT", 0, 0 },
+      { "COMPOUND_TEXT", 0, 0 }
+    };
+  static int n_drag_types = sizeof(drag_types)/sizeof(drag_types[0]);
 
   GTK_WIDGET_SET_FLAGS(view, GTK_CAN_FOCUS | GTK_RECEIVES_DEFAULT);
 
@@ -528,13 +780,7 @@ boardlist_view_init(BoardlistView *view)
 		   G_CALLBACK(tree_view_row_expanded_cb), view);
   g_signal_connect(G_OBJECT(view), "row-collapsed",
 		   G_CALLBACK(tree_view_row_collapsed_cb), view);
-  g_signal_connect(G_OBJECT(view), "button_press_event",
-		   G_CALLBACK(tree_view_button_press_event_cb), view);
-  g_signal_connect(G_OBJECT(view), "button_release_event",
-		   G_CALLBACK(tree_view_button_release_event_cb), view);
-  view->last_event_x = 0.0;
-  view->last_event_y = 0.0;
-  view->last_event_button = 0;
+  view->last_event_path = NULL;
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes(_("Board List"), renderer,
@@ -544,6 +790,20 @@ boardlist_view_init(BoardlistView *view)
 					  decorate_boardlist_entry,
 					  view, NULL);
   gtk_tree_view_append_column(&view->view, column);
+
+  /* D&Dμ¸ */
+  gtk_tree_view_enable_model_drag_dest(&view->view,
+				       drop_types, n_drop_types,
+				       GDK_ACTION_MOVE);
+  g_signal_connect(view, "drag_data_received",
+		   G_CALLBACK(drag_data_received_cb), view);
+
+  gtk_tree_view_enable_model_drag_source(&view->view,
+					 GDK_BUTTON1_MASK,
+					 drag_types, n_drag_types,
+					 GDK_ACTION_COPY | GDK_ACTION_MOVE);
+  g_signal_connect(view, "drag_data_get",
+		   G_CALLBACK(drag_data_get_cb), view);
 }
 
 
@@ -565,10 +825,23 @@ boardlist_view_finalize(GObject *object)
 static void
 boardlist_view_destroy(GtkObject *object)
 {
+  BoardlistView *view = BOARDLIST_VIEW(object);
 #if DEBUG_WIDGET_MOST
   fprintf(stderr, "boardlist_view_destroy\n");
 #endif
 
+  if (view->last_event_path != NULL)
+    {
+      gtk_tree_path_free(view->last_event_path);
+      view->last_event_path = NULL;
+    }
+
+  if (view->last_drag_event_data != NULL)
+    {
+      g_slist_free(view->last_drag_event_data);
+      view->last_drag_event_data = NULL;
+    }
+
   if (GTK_OBJECT_CLASS(parent_class)->destroy)
     (*GTK_OBJECT_CLASS(parent_class)->destroy)(object);
 }
@@ -596,14 +869,14 @@ boardlist_view_expand_category(BoardlistView *view,
 			       OchushaBoardCategory *category)
 {
   gboolean expanded;
-  TreeNodeInfo *info = ensure_node_info(G_OBJECT(category));
+  CategoryNodeInfo *info = ensure_node_info(G_OBJECT(category));
   GtkTreePath *path;
 
-  if (!gtk_tree_store_iter_is_valid(GTK_TREE_STORE(view->model),
-				    &info->iter))
-    return;
+  if (info->reference == NULL)
+    return;	/* 줿ƥξ */
+
+  path = gtk_tree_row_reference_get_path(info->reference);
 
-  path = gtk_tree_model_get_path(GTK_TREE_MODEL(view->model), &info->iter);
   expanded = gtk_tree_view_expand_row(&view->view, path, FALSE);
 
   gtk_tree_path_free(path);
@@ -621,14 +894,14 @@ boardlist_view_collapse_category(BoardlistView *view,
 				 OchushaBoardCategory *category)
 {
   gboolean collapsed;
-  TreeNodeInfo *info = ensure_node_info(G_OBJECT(category));
+  CategoryNodeInfo *info = ensure_node_info(G_OBJECT(category));
   GtkTreePath *path;
 
-  if (!gtk_tree_store_iter_is_valid(GTK_TREE_STORE(view->model),
-				    &info->iter))
-    return;
+  if (info->reference == NULL)
+    return;	/* 줿ƥξ */
+
+  path = gtk_tree_row_reference_get_path(info->reference);
 
-  path = gtk_tree_model_get_path(GTK_TREE_MODEL(view->model), &info->iter);
   collapsed = gtk_tree_view_collapse_row(&view->view, path);
 
   gtk_tree_path_free(path);
@@ -658,7 +931,10 @@ encode_row_state(gboolean hidden, gboolean killed)
 typedef struct _DoOnSelectionArgs
 {
   BoardlistView *view;
-  gint what_to_do;
+  int what_to_do;
+
+  GSList *hidden_boards;
+  GSList *hidden_categories;
 } DoOnSelectionArgs;
 
 
@@ -666,11 +942,10 @@ static void
 do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 		       GtkTreeIter *iter, DoOnSelectionArgs *args)
 {
-  gpointer data;
-  gint what_to_do = args->what_to_do;
+  gpointer data = NULL;
+  int what_to_do = args->what_to_do;
 
-  gtk_tree_model_get(model, iter,
-		     BOARDLIST_DATA, &data, -1);
+  gtk_tree_model_get(model, iter, BOARDLIST_DATA, &data, -1);
   g_return_if_fail(data != NULL);
 
   switch (what_to_do)
@@ -715,6 +990,10 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 			     encode_row_state(category->hidden,
 					      category->killed),
 			     -1);
+	  if (args->view->hide_hidden_items)
+	    args->hidden_categories
+	      = g_slist_append(args->hidden_categories,
+			       gtk_tree_row_reference_new(model, path));
 	}
       else if (OCHUSHA_IS_BULLETIN_BOARD(data))
 	{
@@ -727,6 +1006,10 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 			     BOARDLIST_ROW_STATE,
 			     encode_row_state(board->hidden, board->killed),
 			     -1);
+	  if (args->view->hide_hidden_items)
+	    args->hidden_boards
+	      = g_slist_append(args->hidden_boards,
+			       gtk_tree_row_reference_new(model, path));
 	}
       break;
 
@@ -743,6 +1026,9 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 			     encode_row_state(category->hidden,
 					      category->killed),
 			     -1);
+	  args->hidden_categories
+	    = g_slist_append(args->hidden_categories,
+			     gtk_tree_row_reference_new(model, path));
 	}
       else if (OCHUSHA_IS_BULLETIN_BOARD(data))
 	{
@@ -755,6 +1041,9 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 			     BOARDLIST_ROW_STATE,
 			     encode_row_state(board->hidden, board->killed),
 			     -1);
+	  args->hidden_boards
+	    = g_slist_append(args->hidden_boards,
+			     gtk_tree_row_reference_new(model, path));
 	}
       break;
 
@@ -770,9 +1059,29 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 
 
 static void
-boardlist_view_do_on_selection(BoardlistView *view, gint what_to_do)
+remove_row(gpointer list_data, gpointer user_data)
 {
-  DoOnSelectionArgs args = { view, what_to_do };
+  GtkTreeRowReference *reference = (GtkTreeRowReference *)list_data;
+  GtkTreeStore *store = (GtkTreeStore *)user_data;
+  GtkTreePath *path = gtk_tree_row_reference_get_path(reference);
+  GtkTreeIter iter;
+
+  if (!gtk_tree_model_get_iter(GTK_TREE_MODEL(store), &iter, path))
+    goto done;
+
+  gtk_tree_store_remove(store, &iter);
+
+ done:
+  if (path != NULL)
+    gtk_tree_path_free(path);
+  gtk_tree_row_reference_free(reference);
+}
+
+
+static void
+boardlist_view_do_on_selection(BoardlistView *view, int what_to_do)
+{
+  DoOnSelectionArgs args = { view, what_to_do, NULL, NULL };
 #if DEBUG_WIDGET_MOST
   fprintf(stderr, "boardlist_view_do_on_selection: view=%p what_to_do=%d\n",
 	  view, what_to_do);
@@ -783,12 +1092,24 @@ boardlist_view_do_on_selection(BoardlistView *view, gint what_to_do)
 			(GtkTreeSelectionForeachFunc)do_on_selection_helper,
 			&args);
 
+  if (args.hidden_boards != NULL)
+    {
+      g_slist_foreach(args.hidden_boards, remove_row, view->model);
+      g_slist_free(args.hidden_boards);
+    }
+
+  if (args.hidden_categories != NULL)
+    {
+      g_slist_foreach(args.hidden_categories, remove_row, view->model);
+      g_slist_free(args.hidden_categories);
+    }
+
   ENTER_MAIN_EVENT_LOOP();
 }
 
 
 static void
-boardlist_view_do_on_item_at_cursor(BoardlistView *view, gint what_to_do)
+boardlist_view_do_on_item_at_cursor(BoardlistView *view, int what_to_do)
 {
   GtkTreeIter iter;
   GtkTreePath *path = NULL;
@@ -873,6 +1194,19 @@ popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
 }
 
 
+static void
+popup_menu_callback2(gpointer data, guint action, GtkWidget *widget)
+{
+  BoardlistView *view = gtk_item_factory_popup_data(popup_menu_item_factory2);
+#if DEBUG_WIDGET_MOST
+  fprintf(stderr,
+	  "<boardlist_view.c> popup_menu_callback: view=%p, action=%d\n",
+	  view, action);
+#endif
+  boardlist_view_do_on_selection(view, action);
+}
+
+
 static void
 popup_menu_destructed_cb(gpointer data)
 {
@@ -892,20 +1226,22 @@ boardlist_view_new(void)
 
 
 static gboolean
-tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
-				BoardlistView *view)
+boardlist_view_button_press(GtkWidget *widget, GdkEventButton *event)
 {
+  BoardlistView *view;
   GtkTreeIter iter;
   GtkTreePath *path = NULL;
-  gint row_type;
-  gpointer data = NULL;
   gboolean result = FALSE;
 
+  view = BOARDLIST_VIEW(widget);
+
   MAIN_THREAD_EVENT_CALLBACK();
 
-  view->last_event_x = event->x;
-  view->last_event_y = event->y;
-  view->last_event_button = event->button;
+  if (view->last_event_path != NULL)
+    {
+      gtk_tree_path_free(view->last_event_path);
+      view->last_event_path = NULL;
+    }
 
   if (!gtk_tree_view_get_path_at_pos(&view->view, event->x, event->y, &path,
 				     NULL, NULL, NULL))
@@ -914,51 +1250,45 @@ tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
   if (!gtk_tree_model_get_iter(view->model, &iter, path))
     goto done;
 
-  gtk_tree_model_get(view->model, &iter,
-		     BOARDLIST_ROW_TYPE, &row_type,
-		     BOARDLIST_DATA, &data,
-		     -1);
-
-  if (data == NULL)
-    goto done;
-
   if (event->button == 3)
     {
-      gtk_item_factory_popup_with_data(popup_menu_item_factory,
-				       view, popup_menu_destructed_cb,
-				       event->x_root, event->y_root,
-				       event->button,
-				       gtk_get_current_event_time());
-      if (gtk_tree_selection_iter_is_selected(view->selection, &iter))
-	result = TRUE;
+      if (view->hide_hidden_items)
+	gtk_item_factory_popup_with_data(popup_menu_item_factory2,
+					 view, popup_menu_destructed_cb,
+					 event->x_root, event->y_root,
+					 event->button,
+					 gtk_get_current_event_time());
+      else
+	gtk_item_factory_popup_with_data(popup_menu_item_factory,
+					 view, popup_menu_destructed_cb,
+					 event->x_root, event->y_root,
+					 event->button,
+					 gtk_get_current_event_time());
+
+      if (!gtk_tree_selection_iter_is_selected(view->selection, &iter))
+	{
+	  /* XXX: ȡårow򤵤줿֤ˤʤ롣
+	   *      CTRLSHIFT򲡤ʤξˤϰ㤦񤤤
+	   *      ٤ȿˡĤʤΤŶ
+	   *      DnDݡΥСǤϡå줿row
+	   *      ƤʤäˤϤΥʥϥɥ餬FALSE
+	   *      ֤ȤˤꡢGtkTreeView˽Ǥä
+	   *      DnDݡȻƱˡȡܥ󥯥åǤ
+	   *      DnDǧƤʤϤʤΤDnD⡼ɤäƤޤ
+	   *      ݥåץåץ˥塼̥ɥʤΤǡ̯ʸ
+	   *      롣
+	   */
+	  gtk_tree_view_set_cursor(&view->view, path, NULL, FALSE);
+	}
+      result = TRUE;
       goto done;
     }
 
   if ((event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) != 0)
     goto done;
 
-  switch (row_type)
-    {
-    case BOARDLIST_CATEGORY_ROW:
-      g_signal_emit(G_OBJECT(view),
-		    boardlist_view_signals[SELECT_CATEGORY_SIGNAL],
-		    0,
-		    data);
-      break;
-
-    case BOARDLIST_BOARD_ROW:
-      g_signal_emit(G_OBJECT(view),
-		    boardlist_view_signals[OPEN_THREADLIST_VIEW_SIGNAL],
-		    0,
-		    data,
-		    view->default_open_in_tab
-		    ? event->button == 1 : event->button == 2,
-		    FALSE);
-      break;
-
-    default:
-      fprintf(stderr, "GtkTreeModel broken.\n");
-    }
+  view->last_event_path = path;
+  path = NULL;
 
  done:
   ENTER_MAIN_EVENT_LOOP();
@@ -966,24 +1296,84 @@ tree_view_button_press_event_cb(GtkWidget *widget, GdkEventButton *event,
   if (path != NULL)
     gtk_tree_path_free(path);
 
-  return result;
+  if (!result && GTK_WIDGET_CLASS(parent_class)->button_press_event != NULL)
+    return (*GTK_WIDGET_CLASS(parent_class)->button_press_event)(widget,
+								 event);
+  return TRUE;
 }
 
 
 static gboolean
-tree_view_button_release_event_cb(GtkWidget *widget, GdkEventButton *event,
-				  BoardlistView *view)
+boardlist_view_button_release(GtkWidget *widget, GdkEventButton *event)
 {
+  BoardlistView *view = (BoardlistView *)widget;
+  GtkTreePath *path = NULL;
+
+  g_return_val_if_fail(IS_BOARDLIST_VIEW(view), FALSE);
+  g_return_val_if_fail(event != NULL, FALSE);
+
   MAIN_THREAD_EVENT_CALLBACK();
 
-  if (view != NULL)
+  if (event->button != 3 && view->last_event_path != NULL)
     {
-      view->last_event_x = event->x;
-      view->last_event_y = event->y;
-      view->last_event_button = event->button;
+      int row_type;
+      gpointer data = NULL;
+      GtkTreeIter iter;
+      if (!gtk_tree_view_get_path_at_pos(&view->view, event->x, event->y,
+					 &path,
+					 NULL, NULL, NULL))
+	goto done;
+
+      if (gtk_tree_path_compare(path, view->last_event_path) != 0)
+	goto done;
+
+      if (!gtk_tree_model_get_iter(view->model, &iter, path))
+	goto done;
+
+      gtk_tree_model_get(view->model, &iter,
+			 BOARDLIST_ROW_TYPE, &row_type,
+			 BOARDLIST_DATA, &data,
+			 -1);
+
+      switch (row_type)
+	{
+	case BOARDLIST_CATEGORY_ROW:
+	  g_signal_emit(G_OBJECT(view),
+			boardlist_view_signals[SELECT_CATEGORY_SIGNAL],
+			0,
+			data);
+	  break;
+
+	case BOARDLIST_BOARD_ROW:
+	  g_signal_emit(G_OBJECT(view),
+			boardlist_view_signals[OPEN_THREADLIST_VIEW_SIGNAL],
+			0,
+			data,
+			view->default_open_in_tab
+			? event->button == 1 : event->button == 2,
+			FALSE);
+	  break;
+
+	default:
+	  fprintf(stderr, "GtkTreeModel broken.\n");
+	}
+    }
+
+ done:
+  if (path != NULL)
+    gtk_tree_path_free(path);
+
+  if (view->last_event_path != NULL)
+    {
+      gtk_tree_path_free(view->last_event_path);
+      view->last_event_path = NULL;
     }
 
   ENTER_MAIN_EVENT_LOOP();
+
+  if (GTK_WIDGET_CLASS(parent_class)->button_release_event != NULL)
+    return (*GTK_WIDGET_CLASS(parent_class)->button_release_event)(widget,
+								   event);
   return FALSE;
 }
 
@@ -1259,13 +1649,13 @@ append_board(gpointer data, gpointer user_data)
 {
   OchushaBulletinBoard *board = (OchushaBulletinBoard *)data;
   AppendBoardArgs *args = (AppendBoardArgs *)user_data;
-  TreeNodeInfo *info = ensure_node_info(G_OBJECT(board));
+  GtkTreeIter iter;
 
   if (board->hidden && args->really_hide_hidden_items)
     return;
 
-  gtk_tree_store_append(args->store, &info->iter, args->category_iter);
-  gtk_tree_store_set(args->store, &info->iter,
+  gtk_tree_store_append(args->store, &iter, args->category_iter);
+  gtk_tree_store_set(args->store, &iter,
 		     BOARDLIST_LABEL, board->name,
 		     BOARDLIST_ROW_TYPE, BOARDLIST_BOARD_ROW,
 		     BOARDLIST_ROW_STATE, encode_row_state(board->hidden,
@@ -1279,21 +1669,28 @@ static void
 append_category(gpointer data, gpointer user_data)
 {
   OchushaBoardCategory *category = (OchushaBoardCategory *)data;
-  TreeNodeInfo *info = ensure_node_info(G_OBJECT(category));
+  CategoryNodeInfo *info = ensure_node_info(G_OBJECT(category));
   AppendBoardArgs *args = (AppendBoardArgs *)user_data;
+  GtkTreeIter iter;
+  GtkTreePath *path;
 
   if (category->hidden && args->really_hide_hidden_items)
     return;
-  args->category_iter = &info->iter;
 
-  gtk_tree_store_append(args->store, args->category_iter, NULL);
-  gtk_tree_store_set(args->store, args->category_iter,
+  gtk_tree_store_append(args->store, &iter, NULL);
+  gtk_tree_store_set(args->store, &iter,
 		     BOARDLIST_LABEL, category->name,
 		     BOARDLIST_ROW_TYPE, BOARDLIST_CATEGORY_ROW,
 		     BOARDLIST_ROW_STATE, encode_row_state(category->hidden,
 							   category->killed),
 		     BOARDLIST_DATA, category,
 		     -1);
+  path = gtk_tree_model_get_path(GTK_TREE_MODEL(args->store), &iter);
+  info->reference = gtk_tree_row_reference_new(GTK_TREE_MODEL(args->store),
+					       path);
+  gtk_tree_path_free(path);
+
+  args->category_iter = &iter;
 
   g_slist_foreach(category->board_list, append_board, args);
 }
@@ -1310,6 +1707,7 @@ boardlist_view_open(BoardlistView *view, GSList *category_list,
 		/* data */		   G_TYPE_POINTER);
   		/* (OchushaBoardCategory *)  (OchushaBulletinBoard *) */
   AppendBoardArgs args = { NULL, store, really_hide_hidden_items };
+  view->hide_hidden_items = really_hide_hidden_items;
 
   g_slist_foreach(category_list, append_category, &args);
 
