@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.h,v 1.9 2003/12/16 14:50:33 fuyu Exp $
+ * $Id: boardlist_view.h,v 1.11 2004/01/01 17:16:16 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_VIEW_H_
@@ -57,10 +57,11 @@ struct _BoardlistView
 
   GtkTreeSelection *selection;
 
-  gdouble last_event_x;
-  gdouble last_event_y;
-  guint last_event_button;
+  GtkTreePath *last_event_path;
+  GSList *last_drag_event_data;
+  guint last_event_time;
 
+  gboolean hide_hidden_items;
   gboolean default_open_in_tab;
 };
 
