@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.89 2003/12/30 20:48:12 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.94 2004/01/04 06:44:49 fuyu Exp $
  */
 
 #include "config.h"
@@ -171,8 +171,8 @@ static pthread_cond_t thread_list_condition;
 static OchushaBBSThread *popup_thread = NULL;
 static GtkWidget *title_popup_window = NULL;
 static GtkWidget *title_popup_label = NULL;
-static gint title_popup_x_pos = 0;
-static gint title_popup_y_pos = 0;
+static int title_popup_x_pos = 0;
+static int title_popup_y_pos = 0;
 static guint title_popup_delay_id = 0;
 
 
@@ -185,13 +185,17 @@ static guint writing_netstat_id;
 /*
  * ѡgdk_threads_enter()ʴĶǻȤ
  */
+#define TS_BOOL(value)	((value) ? engine->t : engine->f)
 static TSEngine *engine = NULL;
 static TSCellHandle *list_entry_decorate_func;
+static TSCellHandle *calculate_weight_func;
 
 static const char *default_init_scm =
   "(define (list-entry-decorate-default new-responses filter-enabled filter-ok new-thread favorite hidden) (cond (hidden (cons list-entry-fg-hidden list-entry-bg-hidden)) (new-thread (cons list-entry-fg-strong list-entry-bg-strong)) (filter-ok (cons (if new-responses list-entry-fg-emph list-entry-fg-normal) (if filter-enabled list-entry-bg-normal list-entry-bg-emph))) nil))"
   "(define (list-entry-decorate-default-old new-responses filter-enabled filter-ok new-thread favorite hidden) (cons (if hidden list-entry-fg-hidden (if (and new-responses favorite) list-entry-fg-emph list-entry-fg-normal)) (if new-thread list-entry-bg-strong (if (and new-responses filter-ok) list-entry-bg-emph list-entry-bg-normal))))"
-  "(define list-entry-decorate list-entry-decorate-default)";
+  "(define list-entry-decorate list-entry-decorate-default)"
+  "(define (calculate-weight-default rank n_res n_got n_read dead new favorite hidden) (+ (if hidden 100000 0) (if favorite 0 20000) (if (> n_got 0) 0 10000) (if new 0 5000) (if dead 10000 0)))"
+  "(define calculate-weight calculate-weight-default)";
 
 
 void
@@ -251,7 +255,8 @@ prepare_board_ui_initialization(OchushaApplication *application)
 
       list_entry_decorate_func
 	= ts_engine_mk_cell_symbol(engine, "list-entry-decorate");
-
+      calculate_weight_func
+	= ts_engine_mk_cell_symbol(engine, "calculate-weight");
 
       /* ѥǥեȽեɤ߹ */
       scm_file = fopen(PKGDATADIR "/" OCHUSHA_INIT_SCM, "r");
@@ -684,6 +689,10 @@ customize_threadlist_view_contents(OchushaApplication *application,
 	  threadlist_view_append_last_modified(view);
 	  break;
 
+	case 'W':
+	  threadlist_view_append_weight(view);
+	  break;
+
 	default:
 	  fprintf(stderr, "'%c' doesn't match any column\n", *column);
 	  break;
@@ -1282,6 +1291,32 @@ typedef struct _EachThreadArgs
 } EachThreadArgs;
 
 
+static int
+calculate_weight(OchushaBBSThread *thread, BBSThreadGUIInfo *info, int rank)
+{
+  int weight = 0;
+  if (engine != NULL && calculate_weight_func != NULL)
+    {
+      TSCellHandle *result
+	= ts_engine_evalf0(engine, calculate_weight_func,
+			   "%d%d%d%d%C%C%C%C",
+			   rank,
+			   thread->number_of_responses_on_server,
+			   thread->number_of_responses_read,
+			   info->bookmark_response_number,
+			   TS_BOOL(thread->flags & (OCHUSHA_BBS_THREAD_DAT_DROPPED | OCHUSHA_BBS_THREAD_KAKO)),
+			   TS_BOOL(info->view_flags & BBS_THREAD_NEW),
+			   TS_BOOL(info->view_flags & BBS_THREAD_FAVORITE),
+			   TS_BOOL(info->view_flags & BBS_THREAD_HIDDEN));
+
+      if (ts_cell_handle_is_long(result))
+	weight = (int)ts_cell_handle_get_long_value(result);
+      g_object_unref(G_OBJECT(result));
+    }
+  return weight;
+}
+
+
 static gboolean
 each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
 {
@@ -1323,7 +1358,9 @@ each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
 				    (MAX(thread->number_of_responses_on_server,
 					 thread->number_of_responses_read)
 				     - info->bookmark_response_number),
-				    info->view_rank, args->number_of_threads);
+				    info->view_rank, args->number_of_threads,
+				    calculate_weight(thread, info,
+						     args->number_of_threads));
       update_threadlist_entry_style(args->application, view, thread);
 
       OCHU_THREADS_LEAVE();
@@ -1392,6 +1429,9 @@ show_threadlist(WorkerThread *employee, gpointer args)
 
   OCHU_THREADS_ENTER();
 
+  threadlist_view_set_remove_hidden_thread(view,
+					   application->hide_hidden_threads);
+
   if (job_args->increment_ignored)
     {
       gchar message[4096];
@@ -1414,6 +1454,11 @@ show_threadlist(WorkerThread *employee, gpointer args)
       goto finish_job;
     }
 
+  if (application->sort_threadlist_by_weight)
+    threadlist_view_set_sort_mode(view, THREADLIST_SORT_BY_WEIGHT);
+  else
+    threadlist_view_set_sort_mode(view, THREADLIST_SORT_BY_NONE);
+
   OCHU_THREADS_LEAVE();
 
   if (!ochusha_bulletin_board_refresh_threadlist(board, buffer,
@@ -1533,7 +1578,6 @@ update_threadlist_entry_style(OchushaApplication *application,
 
   if (engine != NULL && list_entry_decorate_func != NULL)
     {
-#define TS_BOOL(value)	((value) ? engine->t : engine->f)
       gboolean filter_result
 	= threadlist_filter_check_thread(&board_info->filter,
 					 application, thread);
@@ -1587,7 +1631,9 @@ update_threadlist_entry_style(OchushaApplication *application,
   threadlist_view_update_thread(view, thread, info->num_shown,
 				(MAX(thread->number_of_responses_on_server,
 				     thread->number_of_responses_read)
-				 - info->bookmark_response_number));
+				 - info->bookmark_response_number),
+				calculate_weight(thread, info,
+						 info->view_rank));
   threadlist_view_update_thread_visual(view, thread, &visual_parameter);
 }
 
@@ -1673,6 +1719,7 @@ reset_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
   ochusha_bbs_thread_remove_cache(thread, &application->config);
   info->view_flags = 0;
+  info->bookmark_response_number = 0;
   update_threadlist_entry_style(application, view, thread);
 }
 
@@ -1944,7 +1991,9 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
 				thread, info->num_shown,
 				(MAX(thread->number_of_responses_on_server,
 				     thread->number_of_responses_read)
-				 - info->bookmark_response_number));
+				 - info->bookmark_response_number),
+				calculate_weight(thread, info,
+						 info->view_rank));
 
   if (info->scroller_id != 0)
     {
@@ -2261,7 +2310,7 @@ background_write_response(WorkerThread *employee, gpointer job_args)
 
 
 static void
-write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
+write_dialog_response_cb(GtkWidget *write_dialog, int response_id,
 			 OchushaApplication *application)
 {
   OchushaBBSThread *thread = g_object_get_data(G_OBJECT(write_dialog),
@@ -2422,7 +2471,7 @@ refresh_thread_button_cb(GtkWidget *widget, OchushaApplication *application)
 
 
 static void
-text_search_window_response_cb(TextSearchWindow *window, gint response_id,
+text_search_window_response_cb(TextSearchWindow *window, int response_id,
 			       OchushaApplication *application)
 {
   MAIN_THREAD_EVENT_CALLBACK();
