@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: icon_label.c,v 1.3 2003/12/29 08:47:44 fuyu Exp $
+ * $Id: icon_label.c,v 1.4 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #include "icon_label.h"
@@ -48,8 +48,7 @@ static void icon_label_size_request(GtkWidget *widget,
 				    GtkRequisition *requisition);
 static void icon_label_size_allocate(GtkWidget *widget,
 				     GtkAllocation *allocation);
-static gint icon_label_expose(GtkWidget *widget,
-			      GdkEventExpose *event);
+static int icon_label_expose(GtkWidget *widget, GdkEventExpose *event);
 
 
 GType
@@ -207,7 +206,7 @@ icon_label_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 }
 
 
-static gint
+static int
 icon_label_expose(GtkWidget *widget, GdkEventExpose *event)
 {
   IconLabel *icon_label = ICON_LABEL(widget);
