@@ -19,3 +19,14 @@
 
 (define list-entry-decorate list-entry-decorate-default)
 ;(define list-entry-decorate list-entry-decorate-default-old)
+
+
+(define (calculate-weight-default
+	 rank n-res n-got n-read dead new favorite hidden)
+  (+ (if hidden 100000 0)
+     (if favorite 0 20000)
+     (if (> n-got 0) (- n-got n-res) 10000)
+     (if new 0 5000)
+     (if dead 10000 0)))
+
+(define calculate-weight calculate-weight-default)
