@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.59 2003/12/30 20:48:12 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.65 2004/01/05 13:54:51 fuyu Exp $
  */
 
 #include "config.h"
@@ -78,7 +78,7 @@
 
 #include "ochusha-banner.h"
 #include "ochusha-banner1.h"
-#define XMAS_SPECIAL	1
+#define XMAS_SPECIAL	0
 #ifdef XMAS_SPECIAL
 #include "ochusha-banner2.h"
 #endif
@@ -131,13 +131,13 @@ static void open_debug_console(OchushaApplication *application);
 #endif
 static void open_preference_dialog(OchushaApplication *application);
 static void open_about_dialog(OchushaApplication *application);
-static void about_dialog_response_cb(GtkWidget *dialog, gint response_id,
+static void about_dialog_response_cb(GtkWidget *dialog, int response_id,
 				     gpointer unused);
 
 static void initialize_open_url_dialog(OchushaApplication *application);
 static void open_url_combo_entry_activate_cb(GtkWidget *entry,
 					     GtkDialog *dialog);
-static void open_url_dialog_response_cb(GtkWidget *dialog, gint response_id,
+static void open_url_dialog_response_cb(GtkWidget *dialog, int response_id,
 					OchushaApplication *application);
 static void popup_open_url_dialog(OchushaApplication *application);
 
@@ -304,6 +304,13 @@ ochusha_init_application(OchushaApplication *application)
       MAIN_MENU_REFRESH_THREADLIST_ALL,
       NULL
     },
+    {
+      _("/Thread/_Sort Threadlist by Weight"),
+      NULL,
+      main_menu_callback,
+      MAIN_MENU_SORT_THREADLIST_BY_WEIGHT,
+      (char *)"<CheckItem>",
+    },
     {
       _("/Thread/Hide Hidden Threads"),
       NULL,
@@ -357,7 +364,7 @@ ochusha_init_application(OchushaApplication *application)
     }
   };
   GtkAccelGroup *accel_group;
-  gint nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
+  int nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
 
   GdkGeometry geometry = { 0, 0, 0, 0, 0, 0, 0, 0, 0.0, 0.0, 0 };
   GtkCheckMenuItem *item;
@@ -441,6 +448,11 @@ ochusha_init_application(OchushaApplication *application)
 				MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS));
   gtk_check_menu_item_set_active(item,
 				 application->hide_hidden_boardlist_items);
+  item = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget_by_action(
+				main_menu_item_factory,
+				MAIN_MENU_SORT_THREADLIST_BY_WEIGHT));
+  gtk_check_menu_item_set_active(item,
+				 application->sort_threadlist_by_weight);
   item = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget_by_action(
 				main_menu_item_factory,
 				MAIN_MENU_HIDE_HIDDEN_THREADS));
@@ -983,6 +995,7 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
 
     case MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS:
     case MAIN_MENU_HIDE_HIDDEN_THREADS:
+    case MAIN_MENU_SORT_THREADLIST_BY_WEIGHT:
       {
 	GtkCheckMenuItem *item
 	  = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget_by_action(
@@ -995,9 +1008,13 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
 	    if (application->boardlist_view != NULL)
 	      redraw_boardlist(application);
 	  }
-	else
+	else if (action == MAIN_MENU_HIDE_HIDDEN_THREADS)
 	  application->hide_hidden_threads
 	    = gtk_check_menu_item_get_active(item);
+	else
+	  application->sort_threadlist_by_weight
+	    = gtk_check_menu_item_get_active(item);
+
 	ENTER_MAIN_EVENT_LOOP();
 	return;
       }
@@ -1103,12 +1120,15 @@ write_optional_prefs(gzFile *file, gpointer user_data)
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  show_threadlist_entry_when_thread_selected);
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, threadlist_view_contents);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
+				  sort_threadlist_by_weight);
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, thread_view_font_name);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  enable_transparent_a_bone);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, disable_popup_a_bone);
 
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, hide_bookmark);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, stick_bookmark);
 
   if (application->bookmark_text != NULL
@@ -1232,6 +1252,7 @@ configure_application(OchushaApplication *application)
       application->enable_transparent_a_bone = FALSE;
       application->disable_popup_a_bone = FALSE;
 
+      application->hide_bookmark = FALSE;
       application->stick_bookmark = FALSE;
       application->bookmark_text = G_STRDUP(_("==== My bookmark: I have read above. ===="));
 
@@ -1405,6 +1426,10 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
     application->threadlist_view_contents
       = G_STRDUP(OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS);
 
+  application->sort_threadlist_by_weight
+    = ochusha_utils_get_attribute_boolean(pref_attrs,
+					  "sort_threadlist_by_weight");
+
   application->default_open_in_tab
     = ochusha_utils_get_attribute_boolean(pref_attrs, "default_open_in_tab");
 
@@ -1421,6 +1446,8 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
     = ochusha_utils_get_attribute_boolean(pref_attrs,
 					  "disable_popup_a_bone");
 
+  application->hide_bookmark
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "hide_bookmark");
   application->stick_bookmark
     = ochusha_utils_get_attribute_boolean(pref_attrs, "stick_bookmark");
   application->bookmark_text = NULL;
@@ -1716,7 +1743,7 @@ output_log_cb(OchushaNetworkBroker *broker, const gchar *message,
 
 
 static void
-preference_dialog_response_cb(GtkWidget *widget, gint response_id,
+preference_dialog_response_cb(GtkWidget *widget, int response_id,
 			      OchushaApplication *application)
 {
   MAIN_THREAD_EVENT_CALLBACK();
@@ -2033,6 +2060,13 @@ preference_dialog_response_cb(GtkWidget *widget, gint response_id,
 	  application->select_tab_when_opened
 	    = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
 
+	tmp_data = g_object_get_data(G_OBJECT(widget), "hide_bookmark");
+	if (tmp_data != NULL)
+	  {
+	    application->hide_bookmark
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
 	tmp_data = g_object_get_data(G_OBJECT(widget), "stick_bookmark");
 	if (tmp_data != NULL)
 	  {
@@ -2119,7 +2153,9 @@ build_ochusha_setting_frame(OchushaApplication *application,
   gtk_widget_show(hbox);
   gtk_box_pack_start(GTK_BOX(outer_vbox), hbox, FALSE, FALSE, 0);
 
+#if 0
   gtk_frame_set_shadow_type(GTK_FRAME(ochusha_frame), GTK_SHADOW_ETCHED_OUT);
+#endif
   gtk_widget_show(outer_vbox);
   gtk_container_add(GTK_CONTAINER(ochusha_frame), outer_vbox);
 
@@ -2319,8 +2355,10 @@ build_threadlist_view_setting_frame(OchushaApplication *application,
   GtkWidget *vbox;
   GtkWidget *tmp_widget;
 
+#if 0
   gtk_frame_set_shadow_type(GTK_FRAME(threadlist_frame),
 			    GTK_SHADOW_ETCHED_OUT);
+#endif
   gtk_widget_show(outer_vbox);
   gtk_container_add(GTK_CONTAINER(threadlist_frame), outer_vbox);
 
@@ -2355,7 +2393,9 @@ build_threadlist_view_setting_frame(OchushaApplication *application,
   g_object_set_data(G_OBJECT(dialog), "show_threadlist_entry",
 		    tmp_widget);
 
+#if 0
   gtk_frame_set_shadow_type(GTK_FRAME(filter_frame), GTK_SHADOW_ETCHED_OUT);
+#endif
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_widget_show(vbox);
   gtk_container_add(GTK_CONTAINER(filter_frame), vbox);
@@ -2387,7 +2427,9 @@ build_thread_view_setting_frame(OchushaApplication *application,
   GtkWidget *hbox;
   GtkObject *adjustment;
 
+#if 0
   gtk_frame_set_shadow_type(GTK_FRAME(outer_frame), GTK_SHADOW_ETCHED_OUT);
+#endif
   gtk_widget_show(outer_vbox);
   gtk_container_add(GTK_CONTAINER(outer_frame), outer_vbox);
 
@@ -2459,7 +2501,9 @@ build_thread_view_setting_frame(OchushaApplication *application,
 
 
   thread_frame = gtk_frame_new(_("Default Setting of Thread Views"));
+#if 0
   gtk_frame_set_shadow_type(GTK_FRAME(thread_frame), GTK_SHADOW_ETCHED_OUT);
+#endif
 
   vbox = gtk_vbox_new(FALSE, 0);
 
@@ -2534,11 +2578,20 @@ build_bookmark_setting_frame(OchushaApplication *application,
   GtkTextBuffer *text_buffer;
   GtkTextIter iter;
 
+#if 0
   gtk_frame_set_shadow_type(GTK_FRAME(outer_frame), GTK_SHADOW_ETCHED_OUT);
+#endif
   gtk_widget_show(outer_vbox);
   gtk_container_add(GTK_CONTAINER(outer_frame), outer_vbox);
 
 
+  tmp_widget = gtk_check_button_new_with_label(_("Do NOT Show Bookmarks."));
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "hide_bookmark", tmp_widget);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->hide_bookmark);
+
   tmp_widget = gtk_radio_button_new_with_label(NULL, _("Do NOT Move Bookmarks Automatically."));
   gtk_widget_show(tmp_widget);
   gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
@@ -2565,8 +2618,10 @@ build_bookmark_setting_frame(OchushaApplication *application,
   tmp_container = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(tmp_container),
 				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#if 0
   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(tmp_container),
 				      GTK_SHADOW_ETCHED_IN);
+#endif
   text_buffer = gtk_text_buffer_new(NULL);
   gtk_text_buffer_get_start_iter(text_buffer, &iter);
   gtk_text_buffer_insert(text_buffer, &iter, application->bookmark_text, -1);
@@ -2584,8 +2639,7 @@ build_bookmark_setting_frame(OchushaApplication *application,
 
 #if ENABLE_DEBUG_CONSOLE
 static void
-debug_console_response_cb(GtkWidget *widget, gint response_id,
-			  gpointer unused)
+debug_console_response_cb(GtkWidget *widget, int response_id, gpointer unused)
 {
   MAIN_THREAD_EVENT_CALLBACK();
 
@@ -2624,8 +2678,10 @@ open_debug_console(OchushaApplication *application)
   scroll = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
 				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#if 0
   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scroll),
 				      GTK_SHADOW_ETCHED_IN);
+#endif
   text_view = gtk_text_view_new_with_buffer(log_buffer);
   gtk_widget_show(text_view);
   gtk_container_add(GTK_CONTAINER(scroll), text_view);
@@ -2737,7 +2793,7 @@ open_about_dialog(OchushaApplication *application)
 	  time_t utc = time(NULL);
 	  localtime_r(&utc, &tm);
 
-	  if (tm.tm_year == 104 && tm.tm_yday < 7)
+	  if (tm.tm_year == 104 && tm.tm_yday < 3)
 	    banner = banner1_pixbuf;
 #ifdef XMAS_SPECIAL
 	  else if (tm.tm_yday >= 357 && tm.tm_yday <= 358)
@@ -2764,7 +2820,7 @@ open_about_dialog(OchushaApplication *application)
 
 
 static void
-about_dialog_response_cb(GtkWidget *widget, gint response_id, gpointer unused)
+about_dialog_response_cb(GtkWidget *widget, int response_id, gpointer unused)
 {
   MAIN_THREAD_EVENT_CALLBACK();
 
@@ -2827,7 +2883,7 @@ open_url_combo_entry_activate_cb(GtkWidget *entry, GtkDialog *dialog)
 
 
 static void
-open_url_dialog_response_cb(GtkWidget *dialog, gint response_id,
+open_url_dialog_response_cb(GtkWidget *dialog, int response_id,
 			    OchushaApplication *application)
 {
   MAIN_THREAD_EVENT_CALLBACK();
