@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.48 2003/12/30 20:48:12 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.52 2004/01/05 13:38:19 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -44,7 +44,7 @@
 #include <gtk/gtk.h>
 
 
-#define ENABLE_DEBUG_CONSOLE						0
+#define ENABLE_DEBUG_CONSOLE						1
 #define ENABLE_MAIN_TOOLBAR						0
 
 #define OCHUSHA_GTKRC					"ochusha-gtkrc"
@@ -165,16 +165,16 @@ struct _OchushaApplication
 
 
   /* window(ǥե)ʤ */
-  gint x_pos;
-  gint y_pos;
-  gint width;
-  gint height;
-  gint boardlist_width;
-  gint threadlist_height;
+  int x_pos;
+  int y_pos;
+  int width;
+  int height;
+  int boardlist_width;
+  int threadlist_height;
 
 
   /* paneɽˡʤ */
-  gint boardlist_pane_style;
+  int boardlist_pane_style;
   gboolean board_tab_shrinkable;
   guint board_tab_minimum_size;
   gboolean board_tab_enable_tooltips;
@@ -183,13 +183,15 @@ struct _OchushaApplication
   gboolean expand_only_one_category;
 
 
-  gint threadlist_pane_style;
+  int threadlist_pane_style;
   gboolean thread_tab_shrinkable;
   guint thread_tab_minimum_size;
   gboolean thread_tab_enable_tooltips;
   gboolean thread_tab_always_show;
   gboolean show_threadlist_entry_when_thread_selected;
   char *threadlist_view_contents;
+  gboolean sort_threadlist_by_weight;
+
   gboolean default_open_in_tab;
   gboolean select_tab_when_opened;
 
@@ -199,6 +201,7 @@ struct _OchushaApplication
   gboolean enable_transparent_a_bone;
   gboolean disable_popup_a_bone;
 
+  gboolean hide_bookmark;
   gboolean stick_bookmark;
   gchar *bookmark_text;
 
@@ -227,7 +230,7 @@ struct _OchushaApplication
   guint popup_response_delay;
   guint popup_close_delay;
   gboolean enable_smart_popup_placement;
-  gint maximum_number_of_popup_responses;
+  int maximum_number_of_popup_responses;
   gboolean analyze_informal_links;
 
 
@@ -241,6 +244,7 @@ struct _OchushaApplication
 
   OchushaNetworkBroker *broker;
 
+
   /* Ǹν񤭹߻̾ */
   gchar *last_name;
 
@@ -283,6 +287,7 @@ typedef enum
   MAIN_MENU_REFRESH_THREAD_ALL,
   MAIN_MENU_REFRESH_THREADLIST,
   MAIN_MENU_REFRESH_THREADLIST_ALL,
+  MAIN_MENU_SORT_THREADLIST_BY_WEIGHT,
   MAIN_MENU_HIDE_HIDDEN_THREADS,
   MAIN_MENU_DEBUG_CONSOLE,
   MAIN_MENU_OPTIONS,
