@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.13 2003/12/30 20:48:12 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.14 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -65,13 +65,13 @@ static ItemViewRelation *item_view_relation_new(gpointer item,
 						GtkWidget *item_view,
 						GtkWidget *menu_item,
 						GtkWidget *tab_label);
-static gint compare_items(gconstpointer list_data, gconstpointer user_data);
+static int compare_items(gconstpointer list_data, gconstpointer user_data);
 static ItemViewRelation *find_item_view_relation(PanedNotebook *paned_notebook,
 						 gconstpointer key);
 static void foreach_item(gpointer data, gpointer user_data);
 static void foreach_item_view(gpointer data, gpointer user_data);
 
-static void close_nth_page(PanedNotebook *paned_notebook, gint page);
+static void close_nth_page(PanedNotebook *paned_notebook, int page);
 
 static void switch_page_cb(ModNotebook *notebook, ModNotebookPage *page,
 			   guint page_num, PanedNotebook *paned_notebook);
@@ -161,7 +161,7 @@ enum {
 
 
 static GtkPanedClass *parent_class = NULL;
-static gint paned_notebook_signals[LAST_SIGNAL] = { 0, 0, 0, 0 };
+static int paned_notebook_signals[LAST_SIGNAL] = { 0, 0, 0, 0 };
 
 
 enum {
@@ -738,7 +738,7 @@ paned_notebook_size_request(GtkWidget *widget, GtkRequisition *requisition)
   if (paned->child1 && GTK_WIDGET_VISIBLE(paned->child1) &&
       paned->child2 && GTK_WIDGET_VISIBLE(paned->child2))
     {
-      gint handle_size;
+      int handle_size;
 
       gtk_widget_style_get(widget, "handle_size", &handle_size, NULL);
       if (paned_notebook->paned_style == HPANED_STYLE)
@@ -754,7 +754,7 @@ paned_notebook_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 {
   PanedNotebook *paned_notebook = PANED_NOTEBOOK(widget);
   GtkPaned *paned = GTK_PANED (widget);
-  gint border_width = GTK_CONTAINER (paned)->border_width;
+  int border_width = GTK_CONTAINER (paned)->border_width;
 
   widget->allocation = *allocation;
 
@@ -765,7 +765,7 @@ paned_notebook_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
       GtkAllocation child2_allocation;
       GtkRequisition child1_requisition;
       GtkRequisition child2_requisition;
-      gint handle_size;
+      int handle_size;
       
       gtk_widget_style_get (widget, "handle_size", &handle_size, NULL);
 
@@ -797,7 +797,7 @@ paned_notebook_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 
 	  paned->handle_pos.x = widget->allocation.x + border_width;
 	  paned->handle_pos.y = widget->allocation.y + paned->child1_size + border_width;
-	  paned->handle_pos.width = MAX(1, (gint) widget->allocation.width - 2 * border_width);
+	  paned->handle_pos.width = MAX(1, (int) widget->allocation.width - 2 * border_width);
 	  paned->handle_pos.height = handle_size;
 	}
       
@@ -826,7 +826,7 @@ paned_notebook_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 
       if (paned_notebook->paned_style == HPANED_STYLE)
 	{
-	  child1_allocation.height = child2_allocation.height = MAX(1, (gint) allocation->height - border_width * 2);
+	  child1_allocation.height = child2_allocation.height = MAX(1, (int) allocation->height - border_width * 2);
 	  child1_allocation.width = paned->child1_size;
 	  child1_allocation.x = widget->allocation.x + border_width;
 	  child1_allocation.y = child2_allocation.y = widget->allocation.y + border_width;
@@ -837,7 +837,7 @@ paned_notebook_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	}
       else
 	{
-	  child1_allocation.width = child2_allocation.width = MAX(1, (gint) allocation->width - border_width * 2);
+	  child1_allocation.width = child2_allocation.width = MAX(1, (int) allocation->width - border_width * 2);
 	  child1_allocation.height = paned->child1_size;
 	  child1_allocation.x = child2_allocation.x = widget->allocation.x + border_width;
 	  child1_allocation.y = widget->allocation.y + border_width;
@@ -980,7 +980,7 @@ item_view_relation_new(gpointer item, GtkWidget *item_view,
 }
 
 
-static gint
+static int
 compare_items(gconstpointer list_data, gconstpointer user_data)
 {
   return (((ItemViewRelation *)list_data)->item != user_data
@@ -1128,7 +1128,7 @@ paned_notebook_open_item_view(PanedNotebook *paned_notebook, gpointer item,
   const gchar *item_title = NULL;
   GtkWidget *tab_label = NULL;
   GtkWidget *menu_item;
-  gint page;
+  int page;
 
   if (item_view != NULL)
     {
@@ -1233,7 +1233,7 @@ void
 paned_notebook_close_item_view(PanedNotebook *paned_notebook, gpointer item)
 {
   ItemViewRelation *relation = find_item_view_relation(paned_notebook, item);
-  gint page;
+  int page;
 
   if (relation == NULL)
     return;
@@ -1254,7 +1254,7 @@ paned_notebook_close_item_view(PanedNotebook *paned_notebook, gpointer item)
 void
 paned_notebook_close_current_item_view(PanedNotebook *paned_notebook)
 {
-  gint page = mod_notebook_get_current_page(paned_notebook->item_contents);
+  int page = mod_notebook_get_current_page(paned_notebook->item_contents);
   if (page == -1)
     return;
 
@@ -1267,7 +1267,7 @@ paned_notebook_close_current_item_view(PanedNotebook *paned_notebook)
  * item_view_closedʥȯԤ롣
  */
 static void
-close_nth_page(PanedNotebook *paned_notebook, gint page)
+close_nth_page(PanedNotebook *paned_notebook, int page)
 {
   ItemViewRelation *relation;
   gpointer item;
@@ -1382,7 +1382,7 @@ button_press_event_cb(ModNotebook *notebook, GdkEventButton *event,
 
   if (event->button == 2)
     {
-      gint page = mod_notebook_get_mouse_event_page_num(notebook,
+      int page = mod_notebook_get_mouse_event_page_num(notebook,
 							(GdkEventAny*)event);
       if (page != -1)
 	{
@@ -1416,7 +1416,7 @@ menu_changed_cb(GtkOptionMenu *option_menu, PanedNotebook *paned_notebook)
 {
   ItemViewRelation *relation;
   GtkMenuItem *menu_item = paned_notebook->active_menu_item;
-  gint page;
+  int page;
 
   if (menu_item == NULL)
     return;
