@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.h,v 1.3 2003/12/30 20:48:12 fuyu Exp $
+ * $Id: paned_notebook.h,v 1.4 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #ifndef _PANED_NOTEBOOK_H_
@@ -101,7 +101,7 @@ struct _PanedNotebook
 
   /* item_contentsɽitemΥꥹ */
   GSList *items_shown;
-  gint number_of_items_shown;
+  int number_of_items_shown;
 
   gpointer current_item;
   GtkWidget *current_item_view;
