@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: session.c,v 1.5 2003/12/30 17:21:46 fuyu Exp $
+ * $Id: session.c,v 1.6 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -61,10 +61,10 @@ ochusha_session_save_states(OchushaApplication *application)
 {
   GtkWidget *widget;
   GtkAllocation *allocation;
-  gint x_pos;
-  gint y_pos;
-  gint sx;
-  gint sy;
+  int x_pos;
+  int y_pos;
+  int sx;
+  int sy;
 
 #if 0
   fprintf(stderr, "ochusha_session_save_states.\n");
