@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: text_search_window.c,v 1.9 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: text_search_window.c,v 1.10 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -98,7 +98,7 @@ enum {
 
 
 static GtkWindowClass *parent_class = NULL;
-static gint text_search_window_signals[LAST_SIGNAL] = { 0, 0, 0 };
+static int text_search_window_signals[LAST_SIGNAL] = { 0, 0, 0 };
 
 
 static void
@@ -500,7 +500,7 @@ text_search_window_update_query(TextSearchWindow *window)
 
 
 static void
-text_search_window_emit_search_signal(TextSearchWindow *window, gint signal_id)
+text_search_window_emit_search_signal(TextSearchWindow *window, int signal_id)
 {
   gboolean result = FALSE;
 
@@ -651,7 +651,7 @@ text_search_window_get_use_regexp(TextSearchWindow *window)
 
 
 void
-text_search_window_response(TextSearchWindow *window, gint response_id)
+text_search_window_response(TextSearchWindow *window, int response_id)
 {
   g_return_if_fail(IS_TEXT_SEARCH_WINDOW(window));
 
