@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.c,v 1.8 2003/12/11 19:38:37 fuyu Exp $
+ * $Id: threadlist_filter.c,v 1.9 2003/12/30 21:53:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -45,8 +45,8 @@
 
 static void threadlist_filter_setting_class_init(ThreadlistFilterSettingClass *klass);
 
-static void append_rule(ThreadlistFilterSetting *setting, gint rule);
-static void remove_rule(ThreadlistFilterSetting *setting, gint rule);
+static void append_rule(ThreadlistFilterSetting *setting, int rule);
+static void remove_rule(ThreadlistFilterSetting *setting, int rule);
 static void append_rule_helper(GtkTreeModel *model, GtkTreePath *path,
 			       GtkTreeIter *iter,
 			       ThreadlistFilterSetting *setting);
@@ -75,7 +75,7 @@ static gboolean all_rules_selection_filter(GtkTreeSelection *selection,
 					   gboolean currently_selected,
 					   ThreadlistFilterSetting *setting);
 static void setup_models(ThreadlistFilterSetting *setting);
-static RuleModelRelation *get_relation_for_rule(ThreadlistFilterSetting *setting, gint rule);
+static RuleModelRelation *get_relation_for_rule(ThreadlistFilterSetting *setting, int rule);
 static void update_models(ThreadlistFilterSetting *setting);
 static void radio_button_toggled_cb(GtkToggleButton *unused,
 				    ThreadlistFilterSetting *setting);
@@ -164,7 +164,7 @@ enum {
 
 
 static GtkVBoxClass *parent_class = NULL;
-static gint threadlist_filter_setting_signals[LAST_SIGNAL] = { 0, 0 };
+static int threadlist_filter_setting_signals[LAST_SIGNAL] = { 0, 0 };
 
 
 static void
@@ -231,7 +231,7 @@ enum {
 
 
 static void
-append_rule(ThreadlistFilterSetting *setting, gint rule)
+append_rule(ThreadlistFilterSetting *setting, int rule)
 {
   GtkListStore *store;
   RuleModelRelation *relation = get_relation_for_rule(setting, rule);
@@ -263,7 +263,7 @@ append_rule(ThreadlistFilterSetting *setting, gint rule)
 
 
 static void
-remove_rule(ThreadlistFilterSetting *setting, gint rule)
+remove_rule(ThreadlistFilterSetting *setting, int rule)
 {
   GtkListStore *store;
   RuleModelRelation *relation = get_relation_for_rule(setting, rule);
@@ -299,8 +299,8 @@ static void
 append_rule_helper(GtkTreeModel *model, GtkTreePath *path,
 		   GtkTreeIter *iter, ThreadlistFilterSetting *setting)
 {
-  gint rule;
-  gint priority;
+  int rule;
+  int priority;
 
   gtk_tree_model_get(model, iter,
 		     FILTER_RULE, &rule,
@@ -320,7 +320,7 @@ append_rule_helper(GtkTreeModel *model, GtkTreePath *path,
 static void
 append_rule_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
 {
-  gint last_num_rules = setting->number_of_rules_applied;
+  int last_num_rules = setting->number_of_rules_applied;
 
   gtk_tree_selection_selected_foreach(setting->all_rules_selection,
 			(GtkTreeSelectionForeachFunc)append_rule_helper,
@@ -342,8 +342,8 @@ append_rule_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
 static void
 remove_rule_helper(GtkTreeRowReference *ref, ThreadlistFilterSetting *setting)
 {
-  gint rule;
-  gint priority;
+  int rule;
+  int priority;
   GtkTreeIter iter;
   GtkTreePath *path;
 
@@ -441,7 +441,7 @@ goto_top_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   GList *selected_rules;
   GList *current_rule;
   GtkTreeModel *model;
-  gint new_priority = 0;
+  int new_priority = 0;
   gchar *tmp_pos;
   gboolean changed = FALSE;
 
@@ -459,7 +459,7 @@ goto_top_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   current_rule = selected_rules;
   while (current_rule != NULL)
     {
-      gint rule;
+      int rule;
       GtkTreeIter tmp_iter;
       RuleModelRelation *relation;
       GtkTreePath *path = (GtkTreePath *)current_rule->data;
@@ -524,7 +524,7 @@ go_up_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   GList *selected_rules;
   GList *current_rule;
   GtkTreeModel *model;
-  gint new_priority = 0;
+  int new_priority = 0;
   int i;
   gchar *tmp_pos;
 
@@ -542,7 +542,7 @@ go_up_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   current_rule = selected_rules;
   while (current_rule != NULL)
     {
-      gint rule;
+      int rule;
       GtkTreeIter tmp_iter;
       RuleModelRelation *relation;
       GtkTreePath *path = (GtkTreePath *)current_rule->data;
@@ -639,7 +639,7 @@ go_down_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   GList *selected_rules;
   GList *current_rule;
   GtkTreeModel *model;
-  gint new_priority = 0;
+  int new_priority = 0;
   int i;
   gchar *tmp_pos;
 
@@ -657,7 +657,7 @@ go_down_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   current_rule = selected_rules;
   while (current_rule != NULL)
     {
-      gint rule;
+      int rule;
       GtkTreeIter tmp_iter;
       RuleModelRelation *relation;
       GtkTreePath *path = (GtkTreePath *)current_rule->data;
@@ -759,8 +759,8 @@ goto_bottom_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   GList *selected_rules;
   GList *current_rule;
   GtkTreeModel *model;
-  gint new_priority = 0;
-  gint i;
+  int new_priority = 0;
+  int i;
   gchar *tmp_pos;
 
   selected_rules
@@ -776,7 +776,7 @@ goto_bottom_button_cb(GtkWidget *widget, ThreadlistFilterSetting *setting)
   current_rule = selected_rules;
   while (current_rule != NULL)
     {
-      gint rule;
+      int rule;
       GtkTreeIter tmp_iter;
       RuleModelRelation *relation;
       GtkTreePath *path = (GtkTreePath *)current_rule->data;
@@ -834,8 +834,8 @@ current_rules_row_changed_cb(GtkTreeModel *model,
 			     GtkTreePath *unused, GtkTreeIter *iter,
 			     ThreadlistFilterSetting *setting)
 {
-  gint rule;
-  gint priority;
+  int rule;
+  int priority;
   RuleModelRelation *relation;
 
   gtk_tree_model_get(model, iter,
@@ -859,7 +859,7 @@ current_rules_row_changed_cb(GtkTreeModel *model,
 static void
 update_current_rule_string(ThreadlistFilterSetting *setting)
 {
-  gint largest_priority = -1;
+  int largest_priority = -1;
   const gchar *normal_rules = THREADLIST_FILTER_NORMAL_RULES;
   const gchar *rule = normal_rules;
 
@@ -894,7 +894,7 @@ all_rules_selection_filter(GtkTreeSelection *selection, GtkTreeModel *model,
 			   ThreadlistFilterSetting *setting)
 {
   GtkTreeIter iter;
-  gint priority;
+  int priority;
 
   if (setting->unselecting)
     {
@@ -1414,7 +1414,7 @@ threadlist_filter_setting_new_with_initial_setting(const ThreadlistFilter *filte
 
 
 static RuleModelRelation *
-get_relation_for_rule(ThreadlistFilterSetting *setting, gint rule)
+get_relation_for_rule(ThreadlistFilterSetting *setting, int rule)
 {
   switch (rule)
     {
@@ -1484,8 +1484,8 @@ text_set_cell_data_available_rule(GtkTreeViewColumn *column,
   GValue psrc = { 0, };
   GValue text = { 0, };
   GValue visible = { 0, };
-  gint rule;
-  gint priority;
+  int rule;
+  int priority;
 
   gtk_tree_model_get_value(model, iter, FILTER_RULE, &src);
   rule = g_value_get_int(&src);
@@ -1521,7 +1521,7 @@ text_set_cell_data_applied_rule(GtkTreeViewColumn *column,
   /*  ThreadlistFilter *filter = &setting->filter; */
   GValue src = { 0, };
   GValue text = { 0, };
-  gint rule;
+  int rule;
 
   gtk_tree_model_get_value(model, iter, FILTER_RULE, &src);
   rule = g_value_get_int(&src);
