@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.19 2003/12/30 17:21:46 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.22 2004/01/01 23:05:58 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -49,8 +49,6 @@ extern "C" {
 typedef struct _ThreadlistView ThreadlistView;
 typedef struct _ThreadlistViewClass ThreadlistViewClass;
 
-typedef struct _ThreadlistInfo ThreadlistInfo;
-
 
 typedef enum
 {
@@ -89,16 +87,21 @@ struct _ThreadlistView
   GtkTreeViewColumn *n_res_verbose_column;
   GtkTreeViewColumn *rank_diff_column;
   GtkTreeViewColumn *last_modified_column;
+  GtkTreeViewColumn *weight_column;
 
   GtkTreeSelection *selection;
 
+  GtkTreePath *last_event_path;
+
+  gboolean remove_hidden_thread;
   gboolean default_open_in_tab;
 
   /* Ϣ */
   gboolean (*title_match_func)(const gchar *title, gpointer search_data);
   int last_search_position;
-  GtkTreePath *last_path;
+  GtkTreeRowReference *tail_row;
 
+  int count;
   int last_rank_diff;
 
   OchushaBBSThread *recently_pointed_thread;
@@ -165,6 +168,25 @@ struct _ThreadlistViewClass
 };
 
 
+/*
+ * Υˡѥ᡼
+ */
+typedef enum
+{
+  THREADLIST_SORT_BY_NONE = GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID,
+  THREADLIST_SORT_BY_RANK,
+  THREADLIST_SORT_BY_MARK,
+  THREADLIST_SORT_BY_TITLE,
+  THREADLIST_SORT_BY_N_RESPONSES,
+  THREADLIST_SORT_BY_N_RESPONSES_GOT,
+  THREADLIST_SORT_BY_N_RESPONSES_UNREAD,
+  THREADLIST_SORT_BY_N_RESPONSES_UNGOT,
+  THREADLIST_SORT_BY_N_RESPONSES_VERBOSE,
+  THREADLIST_SORT_BY_LAST_MODIFIED,
+  THREADLIST_SORT_BY_WEIGHT
+} ThreadlistViewSortMode;
+
+
 /*
  * ˤ륨ȥθɤѥ᡼
  */
@@ -193,6 +215,9 @@ typedef struct _ThreadlistEntryVisualParameter
 
 GType threadlist_view_get_type(void);
 GtkWidget *threadlist_view_new(void);
+gboolean threadlist_view_get_remove_hidden_thread(ThreadlistView *view);
+void threadlist_view_set_remove_hidden_thread(ThreadlistView *view,
+					      gboolean remove);
 
 void threadlist_entry_set_foreground_color(ThreadlistEntryForeground color,
 					   const char *color_name);
@@ -203,6 +228,9 @@ gboolean threadlist_view_get_default_open_in_tab(ThreadlistView *view);
 void threadlist_view_set_default_open_in_tab(ThreadlistView *view,
 					     gboolean default_open_in_tab);
 
+void threadlist_view_set_sort_mode(ThreadlistView *view,
+				   ThreadlistViewSortMode mode);
+
 void threadlist_view_append_rank(ThreadlistView *view);
 void threadlist_view_append_mark(ThreadlistView *view);
 void threadlist_view_append_title(ThreadlistView *view);
@@ -214,6 +242,7 @@ void threadlist_view_append_number_of_responses_unread(ThreadlistView *view);
 void threadlist_view_append_number_of_responses_verbose(ThreadlistView *view);
 void threadlist_view_append_rank_difference(ThreadlistView *view);
 void threadlist_view_append_last_modified(ThreadlistView *view);
+void threadlist_view_append_weight(ThreadlistView *view);
 
 void threadlist_view_initialize_default_view(ThreadlistView *view);
 
@@ -223,10 +252,10 @@ void threadlist_view_close(ThreadlistView *view,
 void threadlist_view_append_thread(ThreadlistView *view,
 				   OchushaBBSThread *thread,
 				   int num_shown, int num_unread,
-				   int last_rank, int new_rank);
+				   int last_rank, int new_rank, int weight);
 void threadlist_view_update_thread(ThreadlistView *view,
 				   OchushaBBSThread *thread,
-				   int num_shown, int num_unread);
+				   int num_shown, int num_unread, int weight);
 void threadlist_view_update_thread_visual(ThreadlistView *view,
 				OchushaBBSThread *thread,
 				ThreadlistEntryVisualParameter *parameter);
