@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.h,v 1.3 2003/11/26 04:13:51 fuyu Exp $
+ * $Id: htmlutils.h,v 1.4 2003/12/30 17:22:07 fuyu Exp $
  */
 
 #ifndef _HTMLUTILS_H_
@@ -54,9 +54,9 @@ typedef struct _ElementHandler
 } ElementHandler;
 
 
-void initialize_default_entity_dictionary();
-GHashTable *get_default_entity_dictionary();
-GHashTable *get_reverse_entity_dictionary();
+void initialize_default_entity_dictionary(void);
+GHashTable *get_default_entity_dictionary(void);
+GHashTable *get_reverse_entity_dictionary(void);
 const char *parse_text(ElementHandler *handler, void *context,
 		       const char *text, int len);
 gchar *simple_string_canon(const char *src, int len,
