@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.c,v 1.17 2003/12/29 08:56:16 fuyu Exp $
+ * $Id: ochusha_async_buffer.c,v 1.18 2003/12/30 21:53:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -228,7 +228,7 @@ enum {
 };
 
 
-static gint async_buffer_signals[LAST_SIGNAL] = { 0, };
+static int async_buffer_signals[LAST_SIGNAL] = { 0, };
 
 
 void
