@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.19 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.20 2003/12/30 21:53:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -96,7 +96,7 @@ enum {
 
 
 static GObjectClass *parent_class = NULL;
-static gint bbs_table_signals[LAST_SIGNAL] = { 0, 0, 0, 0 };
+static int bbs_table_signals[LAST_SIGNAL] = { 0, 0, 0, 0 };
 
 static void
 ochusha_bbs_table_class_init(OchushaBBSTableClass *klass)
