@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.h,v 1.3 2003/12/19 03:13:49 fuyu Exp $
+ * $Id: ochusha_bbs_table.h,v 1.4 2003/12/24 03:40:50 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_TABLE_H_
@@ -36,6 +36,8 @@
 #include <glib-object.h>
 #include <glib.h>
 
+#include <zlib.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -77,13 +79,13 @@ struct _OchushaBBSTableClass
 					  GHashTable *category_attributes);
   void (*boardlist_write_category_element)(OchushaBBSTable *table,
 					   OchushaBoardCategory *category,
-					   FILE *boardlist_xml);
+					   gzFile *boardlist_xml);
   void (*boardlist_read_board_element)(OchushaBBSTable *table,
 				       OchushaBulletinBoard *board,
 				       GHashTable *board_attributes);
   void (*boardlist_write_board_element)(OchushaBBSTable *table,
 					OchushaBulletinBoard *board,
-					FILE *boardlist_xml);
+					gzFile *boardlist_xml);
 };
 
 
@@ -117,9 +119,11 @@ gboolean ochusha_bbs_table_check_url(OchushaBBSTable *table, const char *url,
 				     gboolean *is_kako_html_p);
 
 gboolean ochusha_bbs_table_read_boardlist_xml(OchushaBBSTable *table,
-					      OchushaConfig *conf);
+					      OchushaConfig *conf,
+					      const char *subdir);
 gboolean ochusha_bbs_table_write_boardlist_xml(OchushaBBSTable *table,
-					       OchushaConfig *conf);
+					       OchushaConfig *conf,
+					       const char *subdir);
 
 #ifdef __cplusplus
 } // extern "C"
