@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.20 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.21 2003/12/30 21:53:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -107,7 +107,7 @@ enum {
 
 
 static GObjectClass *parent_class = NULL;
-static gint bbs_thread_signals[LAST_SIGNAL] = { 0, 0 };
+static int bbs_thread_signals[LAST_SIGNAL] = { 0, 0 };
 
 
 static void
