@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.17 2003/12/19 03:13:49 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.18 2003/12/24 03:40:50 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -86,7 +86,7 @@ struct _OchushaBBSThreadClass
   void (*read_threadlist_element)(OchushaBBSThread *thread,
 				  GHashTable *thread_attributes);
   void (*write_threadlist_element)(OchushaBBSThread *thread,
-				   FILE *threadlist_xml);
+				   gzFile *threadlist_xml);
 
 
   /* postξܤˤ륷ʥ */
