@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.c,v 1.9 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_board_category.c,v 1.10 2003/12/30 21:53:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -108,7 +108,7 @@ enum {
 
 
 static GObjectClass *parent_class = NULL;
-static gint board_category_signals[LAST_SIGNAL] = { 0, 0 };
+static int board_category_signals[LAST_SIGNAL] = { 0, 0 };
 
 
 static void
@@ -311,7 +311,7 @@ ochusha_board_category_append_boards(OchushaBoardCategory *category,
 }
 
 
-static gint
+static int
 compare_url(gconstpointer list_data, gconstpointer url)
 {
   return strcmp(((OchushaBulletinBoard *)list_data)->base_url, url);
@@ -333,7 +333,7 @@ ochusha_board_category_lookup_board_by_url(OchushaBoardCategory *category,
 }
 
 
-static gint
+static int
 compare_name(gconstpointer list_data, gconstpointer name)
 {
   return strcmp(((OchushaBulletinBoard *)list_data)->name, name);
