@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.22 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.23 2003/12/30 21:53:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -115,7 +115,7 @@ enum {
 
 
 static GObjectClass *parent_class = NULL;
-static gint bulletin_board_signals[LAST_SIGNAL] = { 0, 0 };
+static int bulletin_board_signals[LAST_SIGNAL] = { 0, 0 };
 
 
 static void
