@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.39 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.41 2004/01/05 12:17:04 fuyu Exp $
  */
 
 #include "config.h"
@@ -111,7 +111,7 @@ enum {
 
 
 static GObjectClass *parent_class = NULL;
-static gint broker_signals[LAST_SIGNAL] = { 0, 0, 0, 0, 0, 0 };
+static int broker_signals[LAST_SIGNAL] = { 0, 0, 0, 0, 0, 0 };
 static GQuark broker_id;
 static GQuark broker_buffer_status_id;
 static GQuark broker_job_args_id;
@@ -2660,7 +2660,7 @@ ochusha_network_broker_try_post(OchushaNetworkBroker *broker,
 				OchushaNetworkBrokerPostStatus *status)
 {
   ghttp_request *request = ghttp_request_new();
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK || DEBUG_POST
   char message[LOG_MESSAGE_SIZE];
 #endif
 
