@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.27 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.30 2004/01/05 14:09:57 fuyu Exp $
  */
 
 #include "config.h"
@@ -1033,10 +1033,6 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
     }
   g_return_val_if_fail(result < PATH_MAX, OCHUSHA_UTILS_2CH_POST_FAILURE);
 
-#if DEBUG_POST_MOST
-  fprintf(stderr, "url: %s\n", url);
-#endif
-
   board_2ch = OCHUSHA_BOARD_2CH(board);
   cookie = ochusha_board_2ch_get_cookie(board_2ch);
   post_result = ochusha_network_broker_try_post(broker, url,
@@ -1050,11 +1046,47 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 	{
 	  const char *x_2ch = strstr(post_status.body, "2ch_X:");
 #if DEBUG_POST_MOST
-	  fprintf(stderr, "Set-Cookie: %s\n", post_status.set_cookie);
-	  fprintf(stderr, "Result-Body: %s\n", post_status.body);
+	  if (post_status.body != NULL)
+	    {
+	      const char *encoding
+		= ochusha_bulletin_board_get_response_character_encoding(board);
+	      iconv_helper *helper
+		= ochusha_bulletin_board_get_response_iconv_helper(board);
+	      iconv_t converter = iconv_open("UTF-8", encoding);
+	      if (converter != (iconv_t)-1)
+		{
+		  gchar *body_utf8 = convert_string(converter, helper,
+						    post_status.body, -1);
+		  if (body_utf8 != NULL)
+		    {
+		      ochusha_network_broker_output_log(broker,
+							"Result-Body: ");
+		      ochusha_network_broker_output_log(broker, body_utf8);
+		      ochusha_network_broker_output_log(broker, "\n");
+		      G_FREE(body_utf8);
+		    }
+		  else
+		    {
+		      ochusha_network_broker_output_log(broker,
+							"iconv_failed.\n");
+		    }
+		  iconv_close(converter);
+		}
+	      else
+		{
+		  ochusha_network_broker_output_log(broker,
+						    "iconv_open failed.\n");
+		}
+	    }
 #endif
+	  if (x_2ch == NULL)
+	    { /* "åǧ" in Shift_JISå */
+	      if (strstr(post_status.body, "\203\116\203\142\203\114\201\133\212\155\224\106\201\111") != NULL)
+		x_2ch = "2ch_X:cookie";	/*  */
+	    }
 	  if (x_2ch != NULL)
 	    {
+	      post_result = FALSE;
 	      if (strstr(x_2ch, "2ch_X:cookie") != NULL)
 		{
 		  new_cookie = post_status.set_cookie;
@@ -1068,15 +1100,8 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 			}
 		    }
 		}
-	      else
-		{
-#if DEBUG_POST_MOST
-		  fprintf(stderr, "Set-Cookie: %s\n", post_status.set_cookie);
-		  fprintf(stderr, "Result-Body: %s\n", post_status.body);
-#endif
-		  post_result = FALSE;
-		}
-#if DEBUG_POST
+
+#if DEBUG_POST && !DEBUG_POST_MOST
 	      if (post_status.body != NULL)
 		{
 		  const char *encoding
@@ -1157,8 +1182,14 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
   if (post_status.set_cookie != NULL)
     G_FREE(post_status.set_cookie);
 
+#if 0
+  if (new_cookie != NULL
+      && (cookie == NULL || strcmp(cookie, new_cookie) != 0))
+    return OCHUSHA_UTILS_2CH_POST_NO_COOKIE;
+#else
   if (new_cookie != NULL)
     return OCHUSHA_UTILS_2CH_POST_NO_COOKIE;
+#endif
 
   return post_result
     ? OCHUSHA_UTILS_2CH_POST_SUCCESS : OCHUSHA_UTILS_2CH_POST_FAILURE;
